#[non_exhaustive]#[repr(u8)]pub enum AuthSecretKey {
Falcon512Rpo(SecretKey),
EcdsaK256Keccak(SecretKey),
}Expand description
Secret keys of the standard AuthSchemes available in the Miden protocol.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Implementations
Sourceimpl AuthSecretKey
impl AuthSecretKey
Sourcepub fn new_falcon512_rpo() -> Self
pub fn new_falcon512_rpo() -> Self
Generates an Falcon512Rpo secret key from the OS-provided randomness.
Sourcepub fn new_falcon512_rpo_with_rng<R: Rng>(rng: &mut R) -> Self
pub fn new_falcon512_rpo_with_rng<R: Rng>(rng: &mut R) -> Self
Generates an Falcon512Rpo secrete key using the provided random number generator.
Sourcepub fn new_ecdsa_k256_keccak() -> Self
pub fn new_ecdsa_k256_keccak() -> Self
Generates an EcdsaK256Keccak secret key from the OS-provided randomness.
Sourcepub fn new_ecdsa_k256_keccak_with_rng<R: Rng + CryptoRng>(rng: &mut R) -> Self
pub fn new_ecdsa_k256_keccak_with_rng<R: Rng + CryptoRng>(rng: &mut R) -> Self
Generates an EcdsaK256Keccak secret key using the provided random number generator.
Sourcepub fn with_scheme_and_rng<R: Rng + CryptoRng>(
scheme: AuthScheme,
rng: &mut R,
) -> Result<Self, AuthSchemeError>
pub fn with_scheme_and_rng<R: Rng + CryptoRng>( scheme: AuthScheme, rng: &mut R, ) -> Result<Self, AuthSchemeError>
Generates a new secret key for the specified authentication scheme using the provided random number generator.
Returns an error if the specified authentication scheme is not supported.
Sourcepub fn with_scheme(scheme: AuthScheme) -> Result<Self, AuthSchemeError>
pub fn with_scheme(scheme: AuthScheme) -> Result<Self, AuthSchemeError>
Generates a new secret key for the specified authentication scheme from the OS-provided randomness.
Returns an error if the specified authentication scheme is not supported.
Sourcepub fn auth_scheme(&self) -> AuthScheme
pub fn auth_scheme(&self) -> AuthScheme
Returns the authentication scheme of this secret key.
Sourcepub fn public_key(&self) -> PublicKey
pub fn public_key(&self) -> PublicKey
Returns a public key associated with this secret key.