pub struct AccountComponentCode(/* private fields */);Expand description
A Library that has been assembled for use as component code.
Implementations
Sourceimpl AccountComponentCode
impl AccountComponentCode
Sourcepub fn as_library(&self) -> &Library
pub fn as_library(&self) -> &Library
Returns a reference to the underlying Library
Sourcepub fn mast_forest(&self) -> &MastForest
pub fn mast_forest(&self) -> &MastForest
Returns a reference to the code’s MastForest
Sourcepub fn into_library(self) -> Library
pub fn into_library(self) -> Library
Consumes self and returns the underlying Library
Sourcepub fn procedure_roots(&self) -> impl Iterator<Item = AccountProcedureRoot> + '_
pub fn procedure_roots(&self) -> impl Iterator<Item = AccountProcedureRoot> + '_
Returns an iterator over the AccountProcedureRoots of this component’s interface
procedures.
Sourcepub fn exports(&self) -> impl Iterator<Item = &ProcedureExport> + '_
pub fn exports(&self) -> impl Iterator<Item = &ProcedureExport> + '_
Returns the interface procedure exports of this component.
A procedure is part of the interface if it has the @account_procedure or @auth_script
attributes.
Sourcepub fn get_procedure_root_by_path(
&self,
proc_name: impl AsRef<Path>,
) -> Option<AccountProcedureRoot>
pub fn get_procedure_root_by_path( &self, proc_name: impl AsRef<Path>, ) -> Option<AccountProcedureRoot>
Returns the AccountProcedureRoot of the procedure with the specified path, or None
if it was not found in this component’s library.
Sourcepub fn with_advice_map(self, advice_map: AdviceMap) -> Self
pub fn with_advice_map(self, advice_map: AdviceMap) -> Self
Returns a new AccountComponentCode with the provided advice map entries merged into the underlying Library’s MastForest.
This allows adding advice map entries to an already-compiled account component, which is useful when the entries are determined after compilation.