pub enum StorageSlotPatch {
Value(StorageValuePatch),
Map(StorageMapPatch),
}Expand description
The patch of a single storage slot.
StorageSlotPatch::Valuecarries theStorageValuePatchfor a value slot.StorageSlotPatch::Mapcarries theStorageMapPatchfor a map slot.
Variants
Value(StorageValuePatch)
Map(StorageMapPatch)
Implementations
Sourceimpl StorageSlotPatch
impl StorageSlotPatch
Sourcepub fn slot_type(&self) -> StorageSlotType
pub fn slot_type(&self) -> StorageSlotType
Returns the StorageSlotType of this slot patch.
Sourcepub fn patch_op(&self) -> StoragePatchOperation
pub fn patch_op(&self) -> StoragePatchOperation
Returns the StoragePatchOperation that this slot patch represents.
Sourcepub fn is_value(&self) -> bool
pub fn is_value(&self) -> bool
Returns true if the slot patch is of type StorageSlotPatch::Value, false otherwise.
Sourcepub fn is_map(&self) -> bool
pub fn is_map(&self) -> bool
Returns true if the slot patch is of type StorageSlotPatch::Map, false otherwise.