pub enum StorageValuePatch {
Create {
value: Word,
},
Update {
value: Word,
},
Remove,
}Expand description
The patch of a single value storage slot.
Variants
Create
Records the creation of the slot with the given value.
Update
Records that an existing slot was set to the given value.
Remove
Records that the slot was removed.
Implementations
Sourceimpl StorageValuePatch
impl StorageValuePatch
Sourcepub fn value(&self) -> Option<Word>
pub fn value(&self) -> Option<Word>
Returns the new value of the slot for StorageValuePatch::Create and
StorageValuePatch::Update, or None for StorageValuePatch::Remove.
Sourcepub fn patch_op(&self) -> StoragePatchOperation
pub fn patch_op(&self) -> StoragePatchOperation
Returns the StoragePatchOperation that this patch represents.