pub struct StorageMapKey(/* private fields */);Expand description
A raw, user-chosen key for a StorageMap.
Storage map keys are user-chosen and thus not necessarily uniformly distributed. To mitigate potential tree imbalance, keys are hashed before being inserted into the underlying SMT.
Use StorageMapKey::hash to produce the corresponding StorageMapKeyHash that is used
in the SMT.
Implementations
Sourceimpl StorageMapKey
impl StorageMapKey
Sourcepub fn from_raw(word: Word) -> Self
pub fn from_raw(word: Word) -> Self
Construct without further checks from a given Word
Warning
This requires the caller to uphold the guarantees/invariants of this type (if any). Check the type-level documentation for guarantees/invariants.
Sourcepub fn as_elements(&self) -> &[Felt]
pub fn as_elements(&self) -> &[Felt]
Returns the elements representation of this value.
Sourceimpl StorageMapKey
impl StorageMapKey
Sourcepub const SERIALIZED_SIZE: usize = Word::SERIALIZED_SIZE
pub const SERIALIZED_SIZE: usize = Word::SERIALIZED_SIZE
The serialized size of the map key in bytes.
Sourcepub fn new(word: Word) -> Self
pub fn new(word: Word) -> Self
Creates a new StorageMapKey from the given word.
Sourcepub fn from_index(idx: u32) -> Self
pub fn from_index(idx: u32) -> Self
Creates a StorageMapKey from a u32 index.
This is a convenience constructor for the common pattern of using sequential indices
as storage map keys, producing a key of [idx, 0, 0, 0].
Sourcepub fn hash(&self) -> StorageMapKeyHash
pub fn hash(&self) -> StorageMapKeyHash
Hashes this raw map key to produce a StorageMapKeyHash.
Storage map keys are hashed before being inserted into the SMT to ensure a uniform key distribution.