pub struct AccountHeader { /* private fields */ }Expand description
A header of an account which contains information that succinctly describes the state of the components of the account.
The AccountHeader is composed of:
- id: the account ID (
AccountId) of the account. - nonce: the nonce of the account.
- vault_root: a commitment to the account’s vault (super::AssetVault).
- storage_commitment: a commitment to the account’s storage (super::AccountStorage).
- code_commitment: a commitment to the account’s code (super::AccountCode).
Implementations
Sourceimpl AccountHeader
impl AccountHeader
Sourcepub fn new(
id: AccountId,
nonce: Felt,
vault_root: Word,
storage_commitment: Word,
code_commitment: Word,
) -> Self
pub fn new( id: AccountId, nonce: Felt, vault_root: Word, storage_commitment: Word, code_commitment: Word, ) -> Self
Creates a new AccountHeader.
Sourcepub fn to_commitment(&self) -> Word
pub fn to_commitment(&self) -> Word
Returns the commitment of this account.
The commitment of an account is computed as a hash over the account header elements returned
by Self::to_elements. Computing the account commitment requires 2 permutations of the
hash function.
Sourcepub fn vault_root(&self) -> Word
pub fn vault_root(&self) -> Word
Returns the vault root of this account.
Sourcepub fn storage_commitment(&self) -> Word
pub fn storage_commitment(&self) -> Word
Returns the storage commitment of this account.
Sourcepub fn code_commitment(&self) -> Word
pub fn code_commitment(&self) -> Word
Returns the code commitment of this account.
Sourcepub fn to_elements(&self) -> Vec<Felt>
pub fn to_elements(&self) -> Vec<Felt>
Returns the account header encoded to a vector of field elements.
This is a vector of the following field elements:
[
[account_nonce, 0, account_id_suffix, account_id_prefix],
VAULT_ROOT,
STORAGE_COMMITMENT,
CODE_COMMITMENT,
]Trait Implementations
Sourceimpl Clone for AccountHeader
impl Clone for AccountHeader
Sourcefn clone(&self) -> AccountHeader
fn clone(&self) -> AccountHeader
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AccountHeader
impl Debug for AccountHeader
Sourceimpl Deserializable for AccountHeader
impl Deserializable for AccountHeader
Sourcefn read_from<R: ByteReader>(
source: &mut R,
) -> Result<Self, DeserializationError>
fn read_from<R: ByteReader>( source: &mut R, ) -> Result<Self, DeserializationError>
Reads a sequence of bytes from the provided
source, attempts to deserialize these bytes
into Self, and returns the result. Read moreSourcefn read_from_bytes(bytes: &[u8]) -> Result<Self, DeserializationError>
fn read_from_bytes(bytes: &[u8]) -> Result<Self, DeserializationError>
Sourceimpl From<&Account> for AccountHeader
impl From<&Account> for AccountHeader
Sourceimpl From<&PartialAccount> for AccountHeader
impl From<&PartialAccount> for AccountHeader
Sourcefn from(account: &PartialAccount) -> Self
fn from(account: &PartialAccount) -> Self
Converts to this type from the input type.
Sourceimpl From<Account> for AccountHeader
impl From<Account> for AccountHeader
Sourceimpl From<PartialAccount> for AccountHeader
impl From<PartialAccount> for AccountHeader
Sourcefn from(account: PartialAccount) -> Self
fn from(account: PartialAccount) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for AccountHeader
impl PartialEq for AccountHeader
Sourceimpl SequentialCommit for AccountHeader
impl SequentialCommit for AccountHeader
Sourcetype Commitment = Word
type Commitment = Word
A type of the commitment which must be derivable from Word.
Sourcefn to_elements(&self) -> Vec<Felt>
fn to_elements(&self) -> Vec<Felt>
Returns a representation of the object as a sequence of fields elements.
Sourcefn to_commitment(&self) -> Self::Commitment
fn to_commitment(&self) -> Self::Commitment
Computes the commitment to the object. Read more
Sourceimpl Serializable for AccountHeader
impl Serializable for AccountHeader
Sourcefn write_into<W: ByteWriter>(&self, target: &mut W)
fn write_into<W: ByteWriter>(&self, target: &mut W)
Serializes
self into bytes and writes these bytes into the target.Sourcefn get_size_hint(&self) -> usize
fn get_size_hint(&self) -> usize
Returns an estimate of how many bytes are needed to represent self. Read more
impl Eq for AccountHeader
impl StructuralPartialEq for AccountHeader