pub struct StorageMapPatchEntries(/* private fields */);Expand description
The changed entries of a storage map, represented as a map of changed item key
(StorageMapKey) to value (Word). For cleared items the value is Word::empty.
Implementations
Sourceimpl StorageMapPatchEntries
impl StorageMapPatchEntries
Sourcepub fn from_raw(entries: BTreeMap<StorageMapKey, Word>) -> Self
pub fn from_raw(entries: BTreeMap<StorageMapKey, Word>) -> Self
Creates a new set of map patch entries from the provided map.
Sourcepub fn num_entries(&self) -> usize
pub fn num_entries(&self) -> usize
Returns the number of changed entries.
Sourcepub fn as_map(&self) -> &BTreeMap<StorageMapKey, Word>
pub fn as_map(&self) -> &BTreeMap<StorageMapKey, Word>
Returns a reference to the changed entries.
Note that the returned key is the StorageMapKey.
Sourcepub fn insert(&mut self, key: StorageMapKey, value: Word)
pub fn insert(&mut self, key: StorageMapKey, value: Word)
Inserts an entry.
Sourcepub fn as_map_mut(&mut self) -> &mut BTreeMap<StorageMapKey, Word>
pub fn as_map_mut(&mut self) -> &mut BTreeMap<StorageMapKey, Word>
Returns a mutable reference to the underlying map.
Sourcepub fn into_map(self) -> BTreeMap<StorageMapKey, Word>
pub fn into_map(self) -> BTreeMap<StorageMapKey, Word>
Consumes self and returns the underlying map.