Module assembly

Module assembly 

Re-exports

pub use miden_assembly::debuginfo;
pub use miden_assembly::diagnostics;

Modules

mast
MAST forest: a collection of procedures represented as Merkle trees.

Structs

Assembler
The Assembler produces a Merkelized Abstract Syntax Tree (MAST) from Miden Assembly sources, as a Package artifact. In general, packages come in three primary varieties:
DefaultSourceManager
KernelLibrary
A package is a assembled artifact containing:
Library
A package is a assembled artifact containing:
Module
The abstract syntax tree for a single Miden Assembly module.
ModuleParser
This is a wrapper around the lower-level parser infrastructure which handles orchestrating all of the pieces needed to parse a ast::Module from source, and run semantic analysis on it.
Path
A borrowed reference to a subset of a path, e.g. another Path or a PathBuf
ProcedureExport
A procedure exported by a package, along with its digest, signature, and attributes.
ProcedureName
Procedure name.
QualifiedProcedureName
Represents a qualified procedure name, e.g. std::math::u64::add, parsed into it’s constituent Path and ProcedureName components.
SourceFile
A SourceFile represents a single file stored in a super::SourceManager
SourceId
A SourceId represents the index/identifier associated with a unique source file in a SourceManager implementation.
SourceSpan
This represents a span of bytes in a Miden Assembly source file.

Enums

LibraryExport
Represents a named item exported from a package.
Linkage
This represents the way in which a dependent will link against a dependency during assembly.
ModuleKind
Represents the kind of a Module.

Traits

Parse
This trait is meant to be implemented by any type that can be parsed to a Module, to allow methods which expect a Module to accept things like:
SourceManager
SourceManagerSync
SourceManagerSync is a marker trait for SourceManager implementations that are also Send + Sync, and is automatically implemented for any SourceManager that meets those requirements.