pub struct ProcedureExport {
pub path: Arc<Path>,
pub node: Option<MastNodeId>,
pub source_node: Option<DebugSourceNodeId>,
pub digest: Word,
pub signature: Option<FunctionType>,
pub attributes: AttributeSet,
}Expand description
A procedure exported by a package, along with its digest, signature, and attributes.
Fields
path: Arc<Path>The fully-qualified path of the procedure exported by this package.
node: Option<MastNodeId>The id of the MAST root node corresponding to this procedure
This is used for provenance, i.e. tracing which specific node in the package MAST this export corresponds to, when multiple exports may have the same digest (conversely, some procedure roots in the MAST may not be associated with any exports).
Provenance is important because multiple logically distinct procedures may compile to the same MAST digest while retaining distinct export identities. The MAST uses executable node fingerprints to collapse equivalent nodes in the forest. The only way to guarantee that you will get the precise MAST node that corresponds to the specific procedure you’ve named is to use the MAST node, rather than the digest.
NOTE: While one might get the impression that MastNodeId is a unique identifier for each
procedure that gets assembled to the MAST, that isn’t actually true. If multiple nodes have
the same executable fingerprint, they may be collapsed into a single node in the MAST and
have the same MastNodeId.
If this field contains None, the digest is used to resolve a MAST node.
source_node: Option<DebugSourceNodeId>Source/debug occurrence corresponding to this exported procedure, when package debug info is present.
This disambiguates exports that collapse to the same executable MastNodeId but retain
distinct source/debug metadata in the package-owned source occurrence graph.
digest: WordThe digest of the procedure exported by this package.
signature: Option<FunctionType>The type signature of the exported procedure.
attributes: AttributeSetAttributes attached to the exported procedure.
Implementations
Sourceimpl ProcedureExport
impl ProcedureExport
pub fn new( path: Arc<Path>, node: Option<MastNodeId>, digest: Word, signature: Option<FunctionType>, ) -> ProcedureExport
pub fn with_source_node( self, source_node: Option<DebugSourceNodeId>, ) -> ProcedureExport
Sourceimpl ProcedureExport
impl ProcedureExport
pub fn read_from_safe<R>(
source: &mut R,
mast: &MastForest,
) -> Result<ProcedureExport, DeserializationError>where
R: ByteReader,