#[repr(u8)]pub enum AssetComposition {
None = 0,
Fungible = 1,
Custom = 2,
}Expand description
Indicates how an asset is composed (i.e. how its merge/split semantics are defined).
The composition is encoded in the metadata byte of an
AssetVaultKey and determines how the asset is handled by the
asset vault, account delta and faucet logic.
Variants
None = 0
Instances of the asset do not compose. In other words, they are non-fungible.
Fungible = 1
Instances of the asset compose according to the rules of the standard fungible asset.
Custom = 2
Instances of the asset have a custom, faucet-defined composition logic.
Exists for future use; currently effectively disabled.
Implementations
Sourceimpl AssetComposition
impl AssetComposition
Sourcepub const SERIALIZED_SIZE: usize
pub const SERIALIZED_SIZE: usize
The serialized size of an AssetComposition in bytes.
Sourcepub const fn is_none(&self) -> bool
pub const fn is_none(&self) -> bool
Returns true if the composition is AssetComposition::None.
Sourcepub const fn is_fungible(&self) -> bool
pub const fn is_fungible(&self) -> bool
Returns true if the composition is AssetComposition::Fungible.
Sourcepub const fn is_custom(&self) -> bool
pub const fn is_custom(&self) -> bool
Returns true if the composition is AssetComposition::Custom.