pub struct AssetCallbacks { /* private fields */ }Expand description
Configures the callback procedure roots for asset callbacks.
Storage Layout
Self::on_before_asset_added_to_account_slot(): Stores the procedure root of theon_before_asset_added_to_accountcallback. This storage slot is only added if the callback procedure root is not the empty word.Self::on_before_asset_added_to_note_slot(): Stores the procedure root of theon_before_asset_added_to_notecallback. This storage slot is only added if the callback procedure root is not the empty word.
Implementations
Sourceimpl AssetCallbacks
impl AssetCallbacks
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new AssetCallbacks with all callbacks set to the empty word.
Sourcepub fn on_before_asset_added_to_account(self, proc_root: Word) -> Self
pub fn on_before_asset_added_to_account(self, proc_root: Word) -> Self
Sets the on_before_asset_added_to_account callback procedure root.
Sourcepub fn on_before_asset_added_to_note(self, proc_root: Word) -> Self
pub fn on_before_asset_added_to_note(self, proc_root: Word) -> Self
Sets the on_before_asset_added_to_note callback procedure root.
Sourcepub fn on_before_asset_added_to_account_slot() -> &'static StorageSlotName
pub fn on_before_asset_added_to_account_slot() -> &'static StorageSlotName
Returns the StorageSlotName where the on_before_asset_added_to_account callback
procedure root is stored.
Sourcepub fn on_before_asset_added_to_note_slot() -> &'static StorageSlotName
pub fn on_before_asset_added_to_note_slot() -> &'static StorageSlotName
Returns the StorageSlotName where the on_before_asset_added_to_note callback
procedure root is stored.
Sourcepub fn on_before_asset_added_to_account_proc_root(&self) -> Word
pub fn on_before_asset_added_to_account_proc_root(&self) -> Word
Returns the procedure root of the on_before_asset_added_to_account callback.
Sourcepub fn on_before_asset_added_to_note_proc_root(&self) -> Word
pub fn on_before_asset_added_to_note_proc_root(&self) -> Word
Returns the procedure root of the on_before_asset_added_to_note callback.
pub fn into_storage_slots(self) -> Vec<StorageSlot>