pub struct AssetVaultKey { /* private fields */ }Expand description
The unique identifier of an Asset in the AssetVault.
Its Word layout is:
[
asset_id_suffix (64 bits),
asset_id_prefix (64 bits),
[faucet_id_suffix (56 bits) | 7 zero bits | callbacks_enabled (1 bit)],
faucet_id_prefix (64 bits)
]Implementations
Sourceimpl AssetVaultKey
impl AssetVaultKey
Sourcepub const SERIALIZED_SIZE: usize = Word::SERIALIZED_SIZE
pub const SERIALIZED_SIZE: usize = Word::SERIALIZED_SIZE
The serialized size of an AssetVaultKey in bytes.
Serialized as its Word representation (4 field elements).
Sourcepub fn new_native(
asset_id: AssetId,
faucet_id: AccountId,
) -> Result<Self, AssetError>
pub fn new_native( asset_id: AssetId, faucet_id: AccountId, ) -> Result<Self, AssetError>
Creates an AssetVaultKey for a native asset with callbacks disabled.
Errors
Returns an error if:
- the provided ID is not of type
AccountType::FungibleFaucetorAccountType::NonFungibleFaucet - the asset ID limbs are not zero when
faucet_idis of typeAccountType::FungibleFaucet.
Sourcepub fn new(
asset_id: AssetId,
faucet_id: AccountId,
callback_flag: AssetCallbackFlag,
) -> Result<Self, AssetError>
pub fn new( asset_id: AssetId, faucet_id: AccountId, callback_flag: AssetCallbackFlag, ) -> Result<Self, AssetError>
Creates an AssetVaultKey from its parts with the given AssetCallbackFlag.
Errors
Returns an error if:
- the provided ID is not of type
AccountType::FungibleFaucetorAccountType::NonFungibleFaucet - the asset ID limbs are not zero when
faucet_idis of typeAccountType::FungibleFaucet.
Sourcepub fn to_word(&self) -> Word
pub fn to_word(&self) -> Word
Returns the word representation of the vault key.
See the type-level documentation for details.
Sourcepub fn asset_id(&self) -> AssetId
pub fn asset_id(&self) -> AssetId
Returns the AssetId of the vault key that distinguishes different assets issued by the
same faucet.
Sourcepub fn faucet_id(&self) -> AccountId
pub fn faucet_id(&self) -> AccountId
Returns the AccountId of the faucet that issued the asset.
Sourcepub fn callback_flag(&self) -> AssetCallbackFlag
pub fn callback_flag(&self) -> AssetCallbackFlag
Returns the AssetCallbackFlag flag of the vault key.
Sourcepub fn new_fungible(faucet_id: AccountId) -> Option<Self>
pub fn new_fungible(faucet_id: AccountId) -> Option<Self>
Constructs a fungible asset’s key from a faucet ID.
Returns None if the provided ID is not of type
AccountType::FungibleFaucet
Sourcepub fn to_leaf_index(&self) -> LeafIndex<SMT_DEPTH>
pub fn to_leaf_index(&self) -> LeafIndex<SMT_DEPTH>
Returns the leaf index of a vault key.