TokenSymbol

Struct TokenSymbol 

pub struct TokenSymbol(/* private fields */);
Represents a token symbol (e.g. “POL”, “ETH”).

Token Symbols can consist of up to 12 capital Latin characters, e.g. “C”, “ETH”, “MIDEN”.

The symbol is stored as a String and can be converted to a Felt encoding via as_element().

Implementations

Source

impl TokenSymbol

pub const MAX_SYMBOL_LENGTH: usize = 12

Maximum allowed length of the token string.

pub const ALPHABET_LENGTH: u64 = 26

The length of the set of characters that can be used in a token’s name.

pub const MIN_ENCODED_VALUE: u64 = 1

The minimum integer value of an encoded TokenSymbol.

This value encodes the “A” token symbol.

pub const MAX_ENCODED_VALUE: u64 = 2481152873203736562

The maximum integer value of an encoded TokenSymbol.

This value encodes the “ZZZZZZZZZZZZ” token symbol.

pub fn new_unchecked(symbol: &str) -> Self

Constructs a new TokenSymbol from a string, panicking on invalid input.

Panics

Panics if:

  • The length of the provided string is less than 1 or greater than 12.
  • The provided token string contains characters that are not uppercase ASCII.
pub fn new(symbol: &str) -> Result<Self, TokenSymbolError>

Creates a new TokenSymbol instance from the provided token name string.

Errors

Returns an error if:

  • The length of the provided string is less than 1 or greater than 12.
  • The provided token string contains characters that are not uppercase ASCII.
pub fn as_element(&self) -> Felt

Returns the Felt encoding of this token symbol.

The alphabet used in the encoding process consists of the Latin capital letters as defined in the ASCII table, having the length of 26 characters.

The encoding is performed by multiplying the intermediate encoded value by the length of the used alphabet and adding the relative index of the character to it. At the end of the encoding process the length of the initial token string is added to the encoded value.

Relative character index is computed by subtracting the index of the character “A” (65) from the index of the currently processing character, e.g., A = 65 - 65 = 0, B = 66 - 65 = 1, ... , Z = 90 - 65 = 25.