pub struct BatchKernel;Expand description
The batch kernel program: an executable Miden program that proves a batch of transactions.
The kernel takes [BLOCK_COMMITMENT, BATCH_ID] as public inputs and emits
[INPUT_NOTES_COMMITMENT, BATCH_NOTE_TREE_ROOT, batch_expiration_block_num]. See
asm/kernels/batch/main.masm for the input/output contract.
Implementations
Sourceimpl BatchKernel
impl BatchKernel
Sourcepub fn main() -> Program
pub fn main() -> Program
Returns the executable batch kernel program loaded from the build’s OUT_DIR.
Sourcepub fn program_info() -> ProgramInfo
pub fn program_info() -> ProgramInfo
Returns ProgramInfo for the batch kernel program.
The batch kernel does not expose syscalls, so the associated Kernel is empty.
Sourcepub fn prepare_inputs(
proposed_batch: &ProposedBatch,
) -> (StackInputs, AdviceInputs)
pub fn prepare_inputs( proposed_batch: &ProposedBatch, ) -> (StackInputs, AdviceInputs)
Transforms the provided ProposedBatch into the stack and advice inputs needed to
execute the batch kernel.
Sourcepub fn build_input_stack(
block_commitment: Word,
batch_id: BatchId,
) -> StackInputs
pub fn build_input_stack( block_commitment: Word, batch_id: BatchId, ) -> StackInputs
Returns the stack with the public inputs required by the batch kernel.
The initial stack is:
[BLOCK_COMMITMENT, BATCH_ID, pad(8)]Where:
BLOCK_COMMITMENTis the commitment of the batch’s reference block.BATCH_IDis the batch’sBatchId.