ProposedBatch

Struct ProposedBatch 

pub struct ProposedBatch { /* private fields */ }
A proposed batch of transactions with all necessary data to validate it.

See ProposedBatch::new for what a proposed batch expects and guarantees.

This type is fairly large, so consider boxing it.

Implementations

Source

impl ProposedBatch

pub fn new( transactions: Vec<Arc<ProvenTransaction>>, reference_block_header: BlockHeader, partial_blockchain: PartialBlockchain, unauthenticated_note_proofs: BTreeMap<NoteId, NoteInclusionProof>, proof_security_level: u32, ) -> Result<Self, ProposedBatchError>

Creates a new ProposedBatch from the provided parts, verifying every transaction’s execution proof against the transaction kernel.

Errors

Returns an error for any of the batch-validation conditions documented on new_batch_inner, or if a transaction’s proof fails to verify or does not meet proof_security_level.

pub fn transactions(&self) -> &[Arc<ProvenTransaction>]

Returns a slice of the ProvenTransactions in the batch.

pub fn transaction_headers(&self) -> OrderedTransactionHeaders

Returns the ordered set of transactions in the batch.

pub fn account_updates(&self) -> &BTreeMap<AccountId, BatchAccountUpdate>

Returns the map of account IDs mapped to their BatchAccountUpdates.

If an account was updated by multiple transactions, the BatchAccountUpdate is the result of merging the individual updates.

For example, suppose an account’s state before this batch is A and the batch contains two transactions that updated it. Applying the first transaction results in intermediate state B, and applying the second one results in state C. Then the returned update represents the state transition from A to C.

pub fn id(&self) -> BatchId

The ID of this batch. See BatchId for details on how it is computed.

pub fn reference_block_header(&self) -> &BlockHeader

Returns the header of the reference block this batch is proposed for.

pub fn batch_expiration_block_num(&self) -> BlockNumber

Returns the block number at which the batch will expire.

pub fn input_notes(&self) -> &InputNotes<InputNoteCommitment>

Returns the InputNotes of this batch.

pub fn output_notes(&self) -> &[OutputNote]

Returns the output notes of the batch.

This is the aggregation of all output notes by the transactions in the batch, except the ones that were consumed within the batch itself.

pub fn into_parts( self, ) -> (Vec<Arc<ProvenTransaction>>, BlockHeader, PartialBlockchain, BTreeMap<NoteId, NoteInclusionProof>, BatchId, BTreeMap<AccountId, BatchAccountUpdate>, InputNotes<InputNoteCommitment>, Vec<OutputNote>, BlockNumber)

Consumes the proposed batch and returns its underlying parts.