pub struct ProvenBatch { /* private fields */ }Expand description
A transaction batch with an execution proof. Currently, this only carries a skeleton proof which does not attest to anything meaningful.
The batch’s transactions may carry outstanding precompile claims. The batch prover settles them
with a single precompile proof, but that proof is not part of the proven batch (yet), so a party
that holds only a ProvenBatch cannot check those claims. This goes away once the batch
kernel verifies the precompile proof in-circuit, in which case the batch proof will recursively
attest to the veracity of the precompile claims.
Implementations
Sourceimpl ProvenBatch
impl ProvenBatch
Sourcepub fn new(
reference_block_commitment: Word,
reference_block_num: BlockNumber,
account_updates: impl IntoIterator<Item = BatchAccountUpdate>,
input_notes: InputNotes<InputNoteCommitment>,
output_notes: Vec<OutputNote>,
batch_expiration_block_num: BlockNumber,
transactions: OrderedTransactionHeaders,
proof: ExecutionProof,
) -> Result<Self, ProvenBatchError>
pub fn new( reference_block_commitment: Word, reference_block_num: BlockNumber, account_updates: impl IntoIterator<Item = BatchAccountUpdate>, input_notes: InputNotes<InputNoteCommitment>, output_notes: Vec<OutputNote>, batch_expiration_block_num: BlockNumber, transactions: OrderedTransactionHeaders, proof: ExecutionProof, ) -> Result<Self, ProvenBatchError>
Creates a new ProvenBatch from the provided parts and validates its local structural
constraints.
This verifies that the account updates form the state transitions described by the
TransactionHeaders. It also checks the supplied input and output notes for duplicates
and known overlap, but does not verify that they are the correctly aggregated note sets
derived from the transaction headers.
This does not verify the execution proof, per-transaction reference blocks or expiration
block numbers, or note inclusion proofs. Those checks require data which is not present in
a TransactionHeader and must be performed before constructing the proven batch or by a
batch verifier.
Errors
Returns an error if the proof contains precompiles, any local structural limit or invariant is violated, or the aggregate account updates do not match the transaction headers.
Sourcepub fn new_unchecked(
id: BatchId,
reference_block_commitment: Word,
reference_block_num: BlockNumber,
account_updates: BTreeMap<AccountId, BatchAccountUpdate>,
input_notes: InputNotes<InputNoteCommitment>,
output_notes: Vec<OutputNote>,
batch_expiration_block_num: BlockNumber,
transactions: OrderedTransactionHeaders,
proof: ExecutionProof,
) -> Result<Self, ProvenBatchError>
pub fn new_unchecked( id: BatchId, reference_block_commitment: Word, reference_block_num: BlockNumber, account_updates: BTreeMap<AccountId, BatchAccountUpdate>, input_notes: InputNotes<InputNoteCommitment>, output_notes: Vec<OutputNote>, batch_expiration_block_num: BlockNumber, transactions: OrderedTransactionHeaders, proof: ExecutionProof, ) -> Result<Self, ProvenBatchError>
Creates a new ProvenBatch from the provided parts without checking any constraints
except the expiration constraint listed below.
Callers must ensure that the batch satisfies the structural constraints checked by
ProvenBatch::new.
Errors
Returns an error if the batch expiration block number is not greater than the reference block number.
Sourcepub fn id(&self) -> BatchId
pub fn id(&self) -> BatchId
The ID of this batch. See BatchId for details on how it is computed.
Sourcepub fn reference_block_commitment(&self) -> Word
pub fn reference_block_commitment(&self) -> Word
Returns the commitment to the reference block of the batch.
Sourcepub fn reference_block_num(&self) -> BlockNumber
pub fn reference_block_num(&self) -> BlockNumber
Returns the number of the reference block of the batch.
Sourcepub fn batch_expiration_block_num(&self) -> BlockNumber
pub fn batch_expiration_block_num(&self) -> BlockNumber
Returns the block number at which the batch will expire.
Sourcepub fn updated_accounts(&self) -> impl Iterator<Item = AccountId> + use<'_>
pub fn updated_accounts(&self) -> impl Iterator<Item = AccountId> + use<'_>
Returns an iterator over the IDs of all accounts updated in this batch.
Sourcepub fn proof_security_level(&self) -> u32
pub fn proof_security_level(&self) -> u32
Returns the proof security level of the batch.
Sourcepub fn account_updates(&self) -> &BTreeMap<AccountId, BatchAccountUpdate>
pub fn account_updates(&self) -> &BTreeMap<AccountId, BatchAccountUpdate>
Returns the map of account IDs mapped to their BatchAccountUpdates.
If an account was updated by multiple transactions, the BatchAccountUpdate is the result
of merging the individual updates.
For example, suppose an account’s state before this batch is A and the batch contains two
transactions that updated it. Applying the first transaction results in intermediate state
B, and applying the second one results in state C. Then the returned update represents
the state transition from A to C.
Sourcepub fn input_notes(&self) -> &InputNotes<InputNoteCommitment>
pub fn input_notes(&self) -> &InputNotes<InputNoteCommitment>
Returns the input notes supplied for this batch.
Sourcepub fn created_nullifiers(&self) -> impl Iterator<Item = Nullifier> + use<'_>
pub fn created_nullifiers(&self) -> impl Iterator<Item = Nullifier> + use<'_>
Returns an iterator over the nullifiers derived from the supplied input notes.
Sourcepub fn output_notes(&self) -> &[OutputNote]
pub fn output_notes(&self) -> &[OutputNote]
Returns the output notes supplied for this batch.
Sourcepub fn transactions(&self) -> &OrderedTransactionHeaders
pub fn transactions(&self) -> &OrderedTransactionHeaders
Returns the OrderedTransactionHeaders included in this batch.
Sourcepub fn proof(&self) -> &ExecutionProof
pub fn proof(&self) -> &ExecutionProof
Returns the execution proof attached to this batch.
Sourcepub fn into_transactions(self) -> OrderedTransactionHeaders
pub fn into_transactions(self) -> OrderedTransactionHeaders
Consumes self and returns the contained OrderedTransactionHeaders of this batch.