Modules
Structs
- Account
Update Witness - This type encapsulates essentially three components:
- Block
Account Update - Describes the changes made to an account state resulting from executing transactions contained in a block.
- Block
Body - Body of a block in the chain which contains data pertaining to all relevant state changes.
- Block
Header - The header of a block. It contains metadata about the block, commitments to the current state of the chain and the hash of the proof that attests to the integrity of the chain.
- Block
Inputs - The required inputs for building a
ProposedBlock. - Block
Note Index - Index of a block note.
- Block
Note Tree - Wrapper over SimpleSmt<BLOCK_NOTE_TREE_DEPTH> for notes tree.
- Block
Number - A convenience wrapper around a
u32representing the number of a block. - Block
Proof - Represents a proof of a block in the chain.
- Block
Signatures - The set of validator signatures over a block header ordered by validator key.
- Blockchain
- The Merkle Mountain Range defining the Miden blockchain.
- FeeParameters
- The fee-related parameters of a block.
- Proposed
Block - A proposed block with many, but not all constraints of a
ProvenBlockenforced. - Proven
Block - Represents a block in the Miden blockchain that has been signed and proven.
- Signed
Block - Represents a block in the Miden blockchain that has been signed by the validators.
- Validator
Keys - The ordered set of validator public keys authorized to sign a block.
Enums
- Signature
Verification Error - Error returned when verifying
BlockSignaturesagainst a validator set (seeBlockSignatures::verify_against). - Validator
Keys Error - Error returned when constructing an invalid
ValidatorKeysset.
Traits
- SmtBackend
- Extension trait for
SmtBackendReaderthat provides write methods. - SmtBackend
Reader - Abstracts over the read-only operations of the different SMT backends (e.g.
SmtandLargeSmt), so that the block trees can work with either implementation transparently.
Type Aliases
- Output
Note Batch - The set of notes created in a transaction batch with their index in the batch.