Module nullifier_tree

Module nullifier_tree 

Structs

NullifierBlock
The BlockNumber at which a Nullifier was consumed.
NullifierMutationSet
A newtype wrapper around a MutationSet for use in the NullifierTree.
NullifierTree
The sparse merkle tree of all nullifiers in the blockchain.
NullifierWitness
A proof that a certain nullifier is in the nullifier tree with the contained state.
PartialNullifierTree
The partial sparse merkle tree containing the nullifiers of consumed notes.