NullifierTree

Struct NullifierTree 

pub struct NullifierTree<Backend = Smt> { /* private fields */ }
The sparse merkle tree of all nullifiers in the blockchain.

A nullifier can only ever be spent once and its value in the tree is the block number at which it was spent.

The tree guarantees that once a nullifier has been inserted into the tree, its block number does not change. Note that inserting the nullifier multiple times with the same block number is valid.

Implementations

Source

impl<Backend> NullifierTree<Backend>
where Backend: SmtBackendReader<Error = MerkleError>,

pub const DEPTH: u8 = SMT_DEPTH

The depth of the nullifier tree.

pub fn new_unchecked(backend: Backend) -> Self

Creates a new NullifierTree from its inner representation.

Invariants

Assumes the provided SMT upholds the guarantees of the NullifierTree. Specifically:

  • Nullifiers are only spent once and their block numbers do not change.
  • Nullifier leaf values must be valid according to NullifierBlock.
pub fn root(&self) -> Word

Returns the root of the nullifier SMT.

pub fn num_nullifiers(&self) -> usize

Returns the number of spent nullifiers in this tree.

pub fn entries(&self) -> impl Iterator<Item = (Nullifier, BlockNumber)>

Returns an iterator over the nullifiers and their block numbers in the tree.

pub fn open(&self, nullifier: &Nullifier) -> NullifierWitness

Returns a NullifierWitness of the leaf associated with the nullifier.

Conceptually, such a witness is a Merkle path to the leaf, as well as the leaf itself.

This witness is a proof of the current block number of the given nullifier. If that block number is zero, it proves that the nullifier is unspent.

pub fn get_block_num(&self, nullifier: &Nullifier) -> Option<BlockNumber>

Returns the block number for the given nullifier or None if the nullifier wasn’t spent yet.

Source

impl<Backend> NullifierTree<Backend>
where Backend: SmtBackend<Error = MerkleError>,

pub fn compute_mutations<I>( &self, nullifiers: impl IntoIterator<Item = (Nullifier, BlockNumber), IntoIter = I>, ) -> Result<NullifierMutationSet, NullifierTreeError>
where I: Iterator<Item = (Nullifier, BlockNumber)> + Clone,

Computes a mutation set resulting from inserting the provided nullifiers into this nullifier tree.

Errors

Returns an error if:

  • a nullifier in the provided iterator was already spent.
  • the list of provided nullifiers contains duplicates.
pub fn mark_spent( &mut self, nullifier: Nullifier, block_num: BlockNumber, ) -> Result<(), NullifierTreeError>

Marks the given nullifier as spent at the given block number.

Errors

Returns an error if:

  • the nullifier was already spent.
pub fn apply_mutations( &mut self, mutations: NullifierMutationSet, ) -> Result<(), NullifierTreeError>

Applies mutations to the nullifier tree.

Errors

Returns an error if:

  • mutations was computed on a tree with a different root than this one.
Source

impl NullifierTree<Smt>

pub fn with_entries( entries: impl IntoIterator<Item = (Nullifier, BlockNumber)>, ) -> Result<Self, NullifierTreeError>

Creates a new nullifier tree from the provided entries.

This is a convenience method that creates an SMT backend with the provided entries and wraps it in a NullifierTree.

Errors

Returns an error if:

  • the provided entries contain multiple block numbers for the same nullifier.
Source

impl<Backend> NullifierTree<LargeSmt<Backend>>
where Backend: SmtStorage,

pub fn with_storage_from_entries( storage: Backend, entries: impl IntoIterator<Item = (Nullifier, BlockNumber)>, ) -> Result<Self, NullifierTreeError>

Creates a new nullifier tree from the provided entries using the given storage backend

This is a convenience method that creates an SMT on the provided storage backend using the provided entries and wraps it in a NullifierTree.

Errors

Returns an error if:

  • the provided entries contain multiple block numbers for the same nullifier.
Panics

Panics if a storage error is encountered.

pub fn reader( &self, ) -> Result<NullifierTree<LargeSmt<Backend::Reader>>, LargeSmtError>

Returns a read-only nullifier tree backed by a reader view of this tree’s storage.

The returned tree shares the same root and entries as self, but its storage is a read-only snapshot produced by SmtStorage::reader. The returned tree cannot be mutated.