pub struct BlockHeader { /* private fields */ }Expand description
The header of a block. It contains metadata about the block, commitments to the current state of the chain and the hash of the proof that attests to the integrity of the chain.
A block header includes the following fields:
versionspecifies the version of the block header itself. It changes when fields are added to or removed from the header, and when the scheme behind one of the header’s commitments changes, for example the structure of the SMTs or of the MMR.timestampis the time when the block was created, in seconds since UNIX epoch. The u32 is sufficient to represent timestamps up to year 2106.block_numis a unique sequential number of the current block.prev_block_commitmentis the hash of the previous block header.chain_commitmentis a commitment to an MMR of the entire chain where each block is a leaf.account_rootis a commitment to account database.nullifier_rootis a commitment to the nullifier database.note_rootis a commitment to all notes created in the current block.tx_commitmentis a commitment to the set of transaction IDs which affected accounts in the block.validator_configis the set of validator public keys authorized to sign the next block, together with the quorum, seeValidatorConfigfor more details.fee_parametersare the parameters defining the base fees, seeFeeParametersfor more details.protocol_config_commitmentis the commitment to the chain’sProtocolConfig.next_protocol_configis the scheduled protocol upgrade, if any, seeNextProtocolConfigfor more details.sub_commitmentis a sequential hash of all fields except the note_root.commitmentis a 2-to-1 hash of the sub_commitment and the note_root.
Implementations
Sourceimpl BlockHeader
impl BlockHeader
Sourcepub fn new(
prev_block_commitment: Word,
block_num: BlockNumber,
chain_commitment: Word,
account_root: Word,
nullifier_root: Word,
note_root: Word,
tx_commitment: Word,
validator_config: ValidatorConfig,
fee_parameters: FeeParameters,
protocol_config_commitment: Word,
next_protocol_config: Option<NextProtocolConfig>,
timestamp: u32,
) -> Self
pub fn new( prev_block_commitment: Word, block_num: BlockNumber, chain_commitment: Word, account_root: Word, nullifier_root: Word, note_root: Word, tx_commitment: Word, validator_config: ValidatorConfig, fee_parameters: FeeParameters, protocol_config_commitment: Word, next_protocol_config: Option<NextProtocolConfig>, timestamp: u32, ) -> Self
Creates a new block header.
Sourcepub fn commitment(&self) -> Word
pub fn commitment(&self) -> Word
Returns the commitment of the block header.
Sourcepub fn sub_commitment(&self) -> Word
pub fn sub_commitment(&self) -> Word
Returns the sub commitment of the block header.
The sub commitment is a sequential hash of all block header fields except the note root. This is used in the block commitment computation which is a 2-to-1 hash of the sub commitment and the note root [hash(sub_commitment, note_root)]. This procedure is used to make the note root easily accessible without having to unhash the entire header.
Sourcepub fn prev_block_commitment(&self) -> Word
pub fn prev_block_commitment(&self) -> Word
Returns the commitment to the previous block header.
Sourcepub fn block_num(&self) -> BlockNumber
pub fn block_num(&self) -> BlockNumber
Returns the block number.
Sourcepub fn block_epoch(&self) -> u16
pub fn block_epoch(&self) -> u16
Returns the epoch to which this block belongs.
This is the block number shifted right by BlockNumber::EPOCH_LENGTH_EXPONENT.
Sourcepub fn chain_commitment(&self) -> Word
pub fn chain_commitment(&self) -> Word
Returns the chain commitment.
Sourcepub fn account_root(&self) -> Word
pub fn account_root(&self) -> Word
Returns the account database root.
Sourcepub fn nullifier_root(&self) -> Word
pub fn nullifier_root(&self) -> Word
Returns the nullifier database root.
Sourcepub fn validator_config(&self) -> &ValidatorConfig
pub fn validator_config(&self) -> &ValidatorConfig
Returns the validator configuration authorized to sign the next block.
A block’s signatures are verified against the validator_config committed to by its parent
block, not against this field. See the BlockHeader docs for details.
Sourcepub fn tx_commitment(&self) -> Word
pub fn tx_commitment(&self) -> Word
Returns the commitment to all transactions in this block.
The commitment is computed as sequential hash of (transaction_id, account_id) tuples.
This makes it possible for the verifier to link transaction IDs to the accounts which
they were executed against.
Sourcepub fn fee_parameters(&self) -> &FeeParameters
pub fn fee_parameters(&self) -> &FeeParameters
Returns a reference to the FeeParameters in this header.
Sourcepub fn protocol_config_commitment(&self) -> Word
pub fn protocol_config_commitment(&self) -> Word
Returns the commitment to the chain’s
ProtocolConfig.
Sourcepub fn next_protocol_config(&self) -> Option<&NextProtocolConfig>
pub fn next_protocol_config(&self) -> Option<&NextProtocolConfig>
Returns the protocol upgrade scheduled by this block, if any.
Sourcepub fn next_protocol_config_commitment(&self) -> Word
pub fn next_protocol_config_commitment(&self) -> Word
Returns the commitment to the scheduled protocol upgrade, or Word::empty if no upgrade
is scheduled.
Sourcepub fn timestamp(&self) -> u32
pub fn timestamp(&self) -> u32
Returns the timestamp at which the block was created, in seconds since UNIX epoch.
Sourcepub fn epoch_block_num(&self) -> BlockNumber
pub fn epoch_block_num(&self) -> BlockNumber
Returns the block number of the epoch block to which this block belongs.
Sourcepub fn to_elements(&self) -> Vec<Felt>
pub fn to_elements(&self) -> Vec<Felt>
Returns this header as a sequence of field elements.
The element layout is:
[
[version, block_num, timestamp, 0],
PREV_BLOCK_COMMITMENT,
CHAIN_COMMITMENT,
ACCOUNT_ROOT,
NULLIFIER_ROOT,
TX_COMMITMENT,
PROTOCOL_CONFIG_COMMITMENT,
VALIDATOR_CONFIG_COMMITMENT,
NEXT_PROTOCOL_CONFIG_COMMITMENT,
[verification_base_fee, 0, 0, 0],
NOTE_ROOT,
]This is the canonical encoding of a header. It is the layout of the kernel’s block data
memory section and the order in which the header is provided to the kernel, so keep it in
sync with the kernel’s process_block_data procedure.
Note that BlockHeader::commitment is not the sequential hash of these elements: the
note root is hashed separately so that it stays accessible without unhashing the whole
header. All elements but the trailing note root form the preimage of
BlockHeader::sub_commitment.