pub struct BlockNoteTree(/* private fields */);Expand description
Wrapper over SimpleSmt<BLOCK_NOTE_TREE_DEPTH> for notes tree.
Each note leaf is the note ID: hash(note_details_commitment || metadata_commitment).
Implementations
Sourceimpl BlockNoteTree
impl BlockNoteTree
Sourcepub fn with_entries<'a>(
entries: impl IntoIterator<Item = (BlockNoteIndex, &'a NoteHeader)>,
) -> Result<Self, MerkleError>
pub fn with_entries<'a>( entries: impl IntoIterator<Item = (BlockNoteIndex, &'a NoteHeader)>, ) -> Result<Self, MerkleError>
Returns a new BlockNoteTree instantiated with entries set as specified by the provided
entries.
Entry format: (note_index, note_header).
Value of each leaf is computed as:
hash(note_details_commitment || note_metadata_commitment).
All leaves omitted from the entries list are set to crate::EMPTY_WORD.
Errors
Returns an error if:
- The number of entries exceeds the maximum notes tree capacity, that is 2^16.
- The provided entries contain multiple values for the same key.
Sourcepub fn empty() -> Self
pub fn empty() -> Self
Returns a new, empty BlockNoteTree.
Sourcepub fn insert_batch_note_subtree(
&mut self,
batch_idx: u64,
batch_note_tree: BatchNoteTree,
) -> Result<(), MerkleError>
pub fn insert_batch_note_subtree( &mut self, batch_idx: u64, batch_note_tree: BatchNoteTree, ) -> Result<(), MerkleError>
Inserts the given BatchNoteTree as a subtree into the block note tree at the specified
index.
Errors
Returns an error if:
- the given batch index is greater or equal to
MAX_BATCHES_PER_BLOCK
Sourcepub fn open(&self, index: BlockNoteIndex) -> SparseMerklePath
pub fn open(&self, index: BlockNoteIndex) -> SparseMerklePath
Returns merkle path for the note with specified batch/note indexes.