pub struct BlockOutputs { /* private fields */ }Expand description
The public outputs produced by the block kernel.
This is the parsed, typed form of the kernel’s output stack.
Implementations
Sourceimpl BlockOutputs
impl BlockOutputs
Sourcepub const BLOCK_COMMITMENT_WORD_IDX: usize = 0
pub const BLOCK_COMMITMENT_WORD_IDX: usize = 0
The element index at which the block commitment word starts on the output stack.
Sourcepub const NULLIFIER_COMMITMENT_WORD_IDX: usize = 4
pub const NULLIFIER_COMMITMENT_WORD_IDX: usize = 4
The element index at which the nullifier commitment word starts on the output stack.
Sourcepub fn new(block_commitment: Word, nullifier_commitment: Word) -> Self
pub fn new(block_commitment: Word, nullifier_commitment: Word) -> Self
Returns a new BlockOutputs instantiated from the provided data.
Sourcepub fn parse(stack: &StackOutputs) -> Result<Self, BlockOutputError>
pub fn parse(stack: &StackOutputs) -> Result<Self, BlockOutputError>
Parses the block kernel’s output stack into a BlockOutputs.
Errors
Returns BlockOutputError::PaddingNotZero if the cells following the nullifier
commitment (positions 8..16) are not all zero.
Sourcepub fn block_commitment(&self) -> Word
pub fn block_commitment(&self) -> Word
Returns the commitment of the block header created by the block kernel.
Sourcepub fn nullifier_commitment(&self) -> Word
pub fn nullifier_commitment(&self) -> Word
Returns the commitment to the set of nullifiers created in the block.
Sourcepub fn into_stack_outputs(self) -> StackOutputs
pub fn into_stack_outputs(self) -> StackOutputs
Encodes these BlockOutputs into the block kernel’s output stack.
This is the inverse of BlockOutputs::parse; the resulting stack is laid out as:
[BLOCK_COMMITMENT, NULLIFIER_COMMITMENT]Trait Implementations
Sourceimpl Clone for BlockOutputs
impl Clone for BlockOutputs
Sourceimpl Debug for BlockOutputs
impl Debug for BlockOutputs
impl Eq for BlockOutputs
Sourceimpl PartialEq for BlockOutputs
impl PartialEq for BlockOutputs
impl StructuralPartialEq for BlockOutputs