pub enum BackendError {
CorruptedData(String),
DuplicateLineage(LineageId),
Internal(Box<dyn Error + Sync + Send>),
Merkle(MerkleError),
Other(Box<dyn Error + Sync + Send>),
UnknownLineage(LineageId),
Unspecified(String),
}Expand description
The error type for use within Backends.
Variants
CorruptedData(String)
Raised when corrupted data is encountered in the backend.
It exists as a separate error variant to allow the forest itself to handle it better if possible, but should be considered a fatal error.
DuplicateLineage(LineageId)
Raised when there is a conflict between an existing lineage ID and one already in the forest.
Internal(Box<dyn Error + Sync + Send>)
Raised for arbitrary errors that are not derived from user-input. These should be considered fatal by callers, but exist to forward the termination decision up to an appropriate level.
Merkle(MerkleError)
Raised when there is an error with the merkle tree semantics within the backend.
Other(Box<dyn Error + Sync + Send>)
Raised for arbitrary other errors within the backend that are derived from user-input and hence non-fatal.
UnknownLineage(LineageId)
Raised when the backend is queried for a lineage it doesn’t know about.
Unspecified(String)
Raised for other errors in the backend that are user-specified.