pub fn rand_vector<T>(length: usize) -> Vec<T>where
T: Randomizable,Expand description
Generates a random vector of type T with the specified length.
Examples
let vec: Vec<u64> = rand_vector(100);pub fn rand_vector<T>(length: usize) -> Vec<T>where
T: Randomizable,Generates a random vector of type T with the specified length.
let vec: Vec<u64> = rand_vector(100);