Packable

Trait Packable 

pub trait Packable:
    'static
    + Default
    + Copy
    + Send
    + Sync
    + PartialEq
    + Eq { }
A trait to constrain types that can be packed into a packed value.

The Packable trait allows us to specify implementations for potentially conflicting types.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl Packable for Goldilocks

Source

impl Packable for u8

Source

impl Packable for u16

Source

impl Packable for u32

Source

impl Packable for u64

Source

impl Packable for u128

Source

impl<MP> Packable for MontyField31<MP>
where MP: MontyParameters,

Implementors