Module note

Module note 

Structs

Note
A note with all the data required for it to be consumed by executing it against the transaction kernel.
NoteAssets
An asset container for a note.
NoteAttachment
The optional attachment for a Note.
NoteAttachmentContent
The content of a NoteAttachment.
NoteAttachmentHeader
The header metadata for a single note attachment.
NoteAttachmentScheme
The user-defined scheme of a NoteAttachment.
NoteAttachments
A collection of note attachments.
NoteDetails
Details of a note consisting of assets, script, storage, and a serial number.
NoteDetailsCommitment
A commitment to a note’s details, without note metadata.
NoteHeader
Holds the strictly required, public information of a note.
NoteId
The unique identifier of a note.
NoteInclusionProof
Contains the data required to prove inclusion of a note in the canonical chain.
NoteLocation
Contains information about the location of a note.
NoteMetadata
Protocol-level note metadata that combines PartialNoteMetadata with attachment information.
NoteRecipient
Value that describes under which condition a note can be consumed.
NoteScript
An executable program of a note.
NoteScriptRoot
The MAST root of a NoteScript.
NoteStorage
A container for note storage items.
NoteTag
NoteTags are 32-bits of data that serve as best-effort filters for notes.
Nullifier
A note’s nullifier.
PartialNote
A note without detailed recipient information.
PartialNoteMetadata
The user-facing metadata associated with a note.

Enums

NoteFile
A serialized representation of a note.
NoteType