pub struct NoteAttachment { /* private fields */ }Expand description
The optional attachment for a Note.
An attachment is a public extension to a note.
Example use cases:
- Communicate the
NoteDetailsof a private note in encrypted form. - In the context of network transactions, encode the ID of the network account that should consume the note.
- Communicate details to the receiver of a private note to allow deriving the
NoteDetailsof that note. For instance, the payback note of a partial swap note can be private, but the receiver needs to know additional details to fully derive the content of the payback note. They can neither fetch those details from the network, since the note is private, nor is a side-channel available. The note attachment can encode those details.
Next to the content, a note attachment can optionally specify a NoteAttachmentScheme. This
allows a note attachment to describe itself. For example, a network account target attachment
can be identified by a standardized type. For cases when the attachment scheme is known from
content or typing is otherwise undesirable, NoteAttachmentScheme::none can be used.
Implementations
Sourceimpl NoteAttachment
impl NoteAttachment
Sourcepub const MAX_NUM_WORDS: u16 = 256
pub const MAX_NUM_WORDS: u16 = 256
The maximum number of words in an attachment.
Each element holds roughly 8 bytes of data and so this allows for a maximum of 256 * 32 = 2^13 = 8192 bytes.
Sourcepub fn new(
attachment_scheme: NoteAttachmentScheme,
content: NoteAttachmentContent,
) -> Self
pub fn new( attachment_scheme: NoteAttachmentScheme, content: NoteAttachmentContent, ) -> Self
Creates a new NoteAttachment from a user-defined scheme and the provided content.
Sourcepub fn with_word(attachment_scheme: NoteAttachmentScheme, word: Word) -> Self
pub fn with_word(attachment_scheme: NoteAttachmentScheme, word: Word) -> Self
Creates a new note attachment from a single word.
Sourcepub fn with_words(
attachment_scheme: NoteAttachmentScheme,
words: Vec<Word>,
) -> Result<Self, NoteError>
pub fn with_words( attachment_scheme: NoteAttachmentScheme, words: Vec<Word>, ) -> Result<Self, NoteError>
Creates a new note attachment from the provided words.
Errors
Returns an error if:
wordsis empty.- The number of words exceeds
NoteAttachment::MAX_NUM_WORDS.
Sourcepub fn attachment_scheme(&self) -> NoteAttachmentScheme
pub fn attachment_scheme(&self) -> NoteAttachmentScheme
Returns the attachment scheme.
Sourcepub fn content(&self) -> &NoteAttachmentContent
pub fn content(&self) -> &NoteAttachmentContent
Returns a reference to the attachment content.
Sourcepub fn to_commitment(&self) -> Word
pub fn to_commitment(&self) -> Word
Computes the commitment of the attachment.
Sourcepub fn as_elements(&self) -> &[Felt]
pub fn as_elements(&self) -> &[Felt]
Returns the raw elements of this attachment content.
Sourcepub fn to_elements(&self) -> Vec<Felt>
pub fn to_elements(&self) -> Vec<Felt>
Returns the raw elements of this attachment content.
Sourcepub fn num_words(&self) -> u16
pub fn num_words(&self) -> u16
Returns the size of this attachment in words (1 to Self::MAX_NUM_WORDS).