pub struct NoteAttachmentScheme(/* private fields */);Expand description
The user-defined scheme of a NoteAttachment.
A note attachment scheme is an arbitrary 16-bit unsigned integer (max Self::MAX). It is
intended to be used to distinguish one attachment from another, or find a specific attachment in
a note’s attachments.
The scheme is purely a hint, and there is no validation with respect to the attachment content.
In other words, any scheme can be associated with any attachment content. Hence, users should
always validate the contents of an attachment, just like with
NoteStorage.
Value 0 is reserved to signal that the entire attachment is absent and so it is not a valid
scheme.
Value 1 is reserved to signal that the scheme is none. Whenever the kind of attachment is not
standardized or interoperability is unimportant, this none value can be used.
Implementations
Sourceimpl NoteAttachmentScheme
impl NoteAttachmentScheme
Sourcepub const MAX: NoteAttachmentScheme
pub const MAX: NoteAttachmentScheme
The maximum value for a note attachment scheme.
Limited to 2^16 - 2 = 65534 to ensure the felt encoding remains valid when four
schemes are packed into a single felt in the note metadata. Limiting schemes to this value
means at least one bit is always unset which ensures felt validity.
Sourcepub fn new(attachment_scheme: u16) -> Result<Self, NoteError>
pub fn new(attachment_scheme: u16) -> Result<Self, NoteError>
Creates a new NoteAttachmentScheme from a u16.
Errors
Returns an error if attachment_scheme is equal to 0 or exceeds Self::MAX.
Sourcepub const fn new_const(attachment_scheme: u16) -> Self
pub const fn new_const(attachment_scheme: u16) -> Self
Creates a new NoteAttachmentScheme from a u16.
Panics
Panics if attachment_scheme is 0 or exceeds Self::MAX.
Sourcepub const fn none() -> Self
pub const fn none() -> Self
Returns the NoteAttachmentScheme that signals the absence of an attachment scheme.