pub struct NoteAttachments { /* private fields */ }Expand description
A collection of note attachments.
Notes can have up to Self::MAX_COUNT attachments.
The commitment to the attachments is defined as:
- 0 attachments:
EMPTY_WORD - 1+ attachments:
hash(ATTACHMENT_0_COMMITMENT || ... || ATTACHMENT_N_COMMITMENT), i.e., the sequential hash over the individual attachment commitments.
Implementations
Sourceimpl NoteAttachments
impl NoteAttachments
Sourcepub const MAX_NUM_WORDS: u16 = 512
pub const MAX_NUM_WORDS: u16 = 512
The maximum total number of elements across all attachments in a note.
Each element holds roughly 8 bytes of data and so this allows for a maximum of 512 * 32 = 2^14 = 16384 bytes.
Sourcepub fn empty() -> Self
pub fn empty() -> Self
Creates a new empty NoteAttachments collection.
Sourcepub fn new(attachments: Vec<NoteAttachment>) -> Result<Self, NoteError>
pub fn new(attachments: Vec<NoteAttachment>) -> Result<Self, NoteError>
Creates a NoteAttachments from a vector of attachments.
Errors
Returns an error if:
- The number of attachments exceeds
Self::MAX_COUNT. - The total number of words across all attachments exceeds
Self::MAX_NUM_WORDS.
Sourcepub fn get(&self, index: usize) -> Option<&NoteAttachment>
pub fn get(&self, index: usize) -> Option<&NoteAttachment>
Returns the attachment at the given index, if it exists.
Sourcepub fn find(&self, scheme: NoteAttachmentScheme) -> Option<&NoteAttachment>
pub fn find(&self, scheme: NoteAttachmentScheme) -> Option<&NoteAttachment>
Returns the first attachment with the provided scheme, if any.
Sourcepub fn num_attachments(&self) -> u8
pub fn num_attachments(&self) -> u8
Returns the number of attachments.
Sourcepub fn iter(&self) -> impl Iterator<Item = &NoteAttachment>
pub fn iter(&self) -> impl Iterator<Item = &NoteAttachment>
Returns an iterator over the attachments.
Sourcepub fn commitments(&self) -> Vec<Word>
pub fn commitments(&self) -> Vec<Word>
Returns the individual commitment of each contained attachment.
Sourcepub fn to_commitment(&self) -> Word
pub fn to_commitment(&self) -> Word
Returns the commitment over the contained attachments.
Sourcepub fn to_headers(&self) -> [NoteAttachmentHeader; 4]
pub fn to_headers(&self) -> [NoteAttachmentHeader; 4]
Returns the attachment headers for all attachment slots.
Returns a fixed-size array of Self::MAX_COUNT headers. Unused slots are filled with
NoteAttachmentHeader::absent.
Sourcepub fn into_vec(self) -> Vec<NoteAttachment>
pub fn into_vec(self) -> Vec<NoteAttachment>
Consumes self and returns the inner vector of attachments.