pub struct NoteRecipient { /* private fields */ }Expand description
Value that describes under which condition a note can be consumed.
The recipient is not an account address, instead it is a value that describes when a note can be consumed. Because not all notes have predetermined consumer addresses, e.g. swap notes can be consumed by anyone, the recipient is defined as the code and its storage, that when successfully executed results in the note’s consumption.
Recipient is computed as:
hash(hash(hash(serial_num, [0; 4]), script_root), storage_commitment)
Implementations
Sourceimpl NoteRecipient
impl NoteRecipient
pub fn new(serial_num: Word, script: NoteScript, storage: NoteStorage) -> Self
Sourcepub fn serial_num(&self) -> Word
pub fn serial_num(&self) -> Word
The recipient’s serial_num, the secret required to consume the note.
Sourcepub fn script(&self) -> &NoteScript
pub fn script(&self) -> &NoteScript
The recipients’s script which locks the assets of this note.
Sourcepub fn storage(&self) -> &NoteStorage
pub fn storage(&self) -> &NoteStorage
The recipient’s storage which customizes the script’s behavior.
Sourcepub fn digest(&self) -> Word
pub fn digest(&self) -> Word
The recipient’s digest, which commits to its details.
This is the public data required to create a note.
Sourcepub fn minify_script(&mut self)
pub fn minify_script(&mut self)
Reduces the size of the note script by stripping all debug info from it.
Sourcepub fn into_parts(self) -> (Word, NoteScript, NoteStorage)
pub fn into_parts(self) -> (Word, NoteScript, NoteStorage)
Consumes self and returns the underlying parts of the NoteRecipient.