pub struct NoteScript { /* private fields */ }Expand description
An executable program of a note.
A note’s script represents a program which must be executed for a note to be consumed. As such it defines the rules and side effects of consuming a given note.
Implementations
Sourceimpl NoteScript
impl NoteScript
Sourcepub fn new(code: Program) -> Self
pub fn new(code: Program) -> Self
Returns a new NoteScript instantiated from the provided program.
Sourcepub fn from_bytes(bytes: &[u8]) -> Result<Self, NoteError>
pub fn from_bytes(bytes: &[u8]) -> Result<Self, NoteError>
Returns a new NoteScript deserialized from the provided bytes.
Errors
Returns an error if note script deserialization fails.
Sourcepub fn from_parts(mast: Arc<MastForest>, entrypoint: MastNodeId) -> Self
pub fn from_parts(mast: Arc<MastForest>, entrypoint: MastNodeId) -> Self
Returns a new NoteScript instantiated from the provided components.
Panics
Panics if the specified entrypoint is not in the provided MAST forest.
Sourcepub fn from_library(library: &Library) -> Result<Self, NoteError>
pub fn from_library(library: &Library) -> Result<Self, NoteError>
Returns a new NoteScript instantiated from the provided library.
The library must contain exactly one procedure with the @note_script attribute,
which will be used as the entrypoint.
Errors
Returns an error if:
- The library does not contain a procedure with the
@note_scriptattribute. - The library contains multiple procedures with the
@note_scriptattribute.
Sourcepub fn from_library_reference(
library: &Library,
path: &Path,
) -> Result<Self, NoteError>
pub fn from_library_reference( library: &Library, path: &Path, ) -> Result<Self, NoteError>
Returns a new NoteScript containing only a reference to a procedure in the provided library.
This method is useful when a library contains multiple note scripts and you need to
extract a specific one by its fully qualified path (e.g.,
miden::standards::notes::burn::main).
The procedure at the specified path must have the @note_script attribute.
Note: This method creates a minimal MastForest containing only an external node
referencing the procedure’s digest, rather than copying the entire library. The actual
procedure code will be resolved at runtime via the MastForestStore.
Errors
Returns an error if:
- The library does not contain a procedure at the specified path.
- The procedure at the specified path does not have the
@note_scriptattribute.
Sourcepub fn root(&self) -> Word
pub fn root(&self) -> Word
Returns the commitment of this note script (i.e., the script’s MAST root).
Sourcepub fn mast(&self) -> Arc<MastForest>
pub fn mast(&self) -> Arc<MastForest>
Returns a reference to the MastForest backing this note script.
Sourcepub fn entrypoint(&self) -> MastNodeId
pub fn entrypoint(&self) -> MastNodeId
Returns an entrypoint node ID of the current script.
Sourcepub fn with_advice_map(self, advice_map: AdviceMap) -> Self
pub fn with_advice_map(self, advice_map: AdviceMap) -> Self
Returns a new NoteScript with the provided advice map entries merged into the underlying MastForest.
This allows adding advice map entries to an already-compiled note script, which is useful when the entries are determined after script compilation.