pub struct PartialNote { /* private fields */ }Expand description
A note without detailed recipient information.
A partial note consists of PartialNoteMetadata, NoteAssets, NoteAttachments, and a
commitment to the NoteRecipient). However, it does not contain
the full recipient, including note script, note storage, and note’s serial number. This
means that a partial note is sufficient to compute note ID and note header, but not sufficient
to compute note nullifier, and generally does not have enough info to execute the note.
One use case for the PartialNote is to return the details of a private note created during a
transaction, where the assets and attachments are known, but the recipient is not.
Implementations
Sourceimpl PartialNote
impl PartialNote
Sourcepub fn new(
partial_metadata: PartialNoteMetadata,
recipient_digest: Word,
assets: NoteAssets,
attachments: NoteAttachments,
) -> Self
pub fn new( partial_metadata: PartialNoteMetadata, recipient_digest: Word, assets: NoteAssets, attachments: NoteAttachments, ) -> Self
Returns a new PartialNote instantiated from the provided parameters.
Sourcepub fn details_commitment(&self) -> NoteDetailsCommitment
pub fn details_commitment(&self) -> NoteDetailsCommitment
Returns the commitment to the note’s details, excluding metadata.
Sourcepub fn metadata(&self) -> &NoteMetadata
pub fn metadata(&self) -> &NoteMetadata
Returns a reference to the NoteMetadata of this note.
Sourcepub fn partial_metadata(&self) -> &PartialNoteMetadata
pub fn partial_metadata(&self) -> &PartialNoteMetadata
Returns the partial metadata associated with this note.
Sourcepub fn recipient_digest(&self) -> Word
pub fn recipient_digest(&self) -> Word
Returns the digest of the recipient associated with this note.
See super::NoteRecipient for more info.
Sourcepub fn assets(&self) -> &NoteAssets
pub fn assets(&self) -> &NoteAssets
Returns a list of assets associated with this note.
Sourcepub fn attachments(&self) -> &NoteAttachments
pub fn attachments(&self) -> &NoteAttachments
Returns the note’s attachments.
Sourcepub fn header(&self) -> &NoteHeader
pub fn header(&self) -> &NoteHeader
Returns the NoteHeader of this note.
Sourcepub fn into_parts(self) -> (NoteAssets, NoteHeader, NoteAttachments)
pub fn into_parts(self) -> (NoteAssets, NoteHeader, NoteAttachments)
Consumes self and returns the non-Copy parts of this note.