pub fn package_debug_info(package: &Package) -> Option<Arc<PackageDebugInfo>>Expand description
Returns package-owned debug info when it can be decoded from trusted package sections.
pub fn package_debug_info(package: &Package) -> Option<Arc<PackageDebugInfo>>Returns package-owned debug info when it can be decoded from trusted package sections.