pub struct ProtocolConfig { /* private fields */ }Expand description
The configuration parameters of the protocol that are expected to change rarely over the lifetime of a chain.
A BlockHeader holds only the commitment to this config, so that
rarely changing data does not take up space in every block.
Implementations
Sourceimpl ProtocolConfig
impl ProtocolConfig
Sourcepub fn new(
fee_asset_id: AssetId,
tx_kernel: KernelConfig,
batch_kernel: KernelConfig,
block_kernel: KernelConfig,
proof_verification: ProofVerificationConfig,
) -> Result<Self, ProtocolConfigError>
pub fn new( fee_asset_id: AssetId, tx_kernel: KernelConfig, batch_kernel: KernelConfig, block_kernel: KernelConfig, proof_verification: ProofVerificationConfig, ) -> Result<Self, ProtocolConfigError>
Creates a new ProtocolConfig from the provided inputs.
Errors
Returns an error if fee_asset_id is not a fungible asset ID.
Sourcepub fn current(fee_asset_id: AssetId) -> Result<Self, ProtocolConfigError>
pub fn current(fee_asset_id: AssetId) -> Result<Self, ProtocolConfigError>
Creates the ProtocolConfig described by the currently linked kernels.
TODO(#3644): The batch kernel, the block kernel and the proof verification roots are placeholders until those parts of the protocol exist.
Errors
Returns an error if fee_asset_id is not a fungible asset ID.
Sourcepub fn fee_asset_id(&self) -> AssetId
pub fn fee_asset_id(&self) -> AssetId
Returns the ID of the asset that fees are paid in.
Sourcepub fn tx_kernel(&self) -> &KernelConfig
pub fn tx_kernel(&self) -> &KernelConfig
Returns the configuration of the transaction kernel.
Sourcepub fn batch_kernel(&self) -> &KernelConfig
pub fn batch_kernel(&self) -> &KernelConfig
Returns the configuration of the batch kernel.
Sourcepub fn block_kernel(&self) -> &KernelConfig
pub fn block_kernel(&self) -> &KernelConfig
Returns the configuration of the block kernel.
Sourcepub fn proof_verification(&self) -> &ProofVerificationConfig
pub fn proof_verification(&self) -> &ProofVerificationConfig
Returns the parameters defining which proofs the protocol accepts.
Sourcepub fn to_commitment(&self) -> Word
pub fn to_commitment(&self) -> Word
Returns the commitment to this configuration, which is what a block header commits to.
Sourcepub fn to_elements(&self) -> Vec<Felt>
pub fn to_elements(&self) -> Vec<Felt>
Returns the preimage of ProtocolConfig::to_commitment as a sequence of field elements.
The element layout is:
[
FEE_ASSET_ID,
TX_KERNEL_CONFIG_COMMITMENT,
BATCH_KERNEL_CONFIG_COMMITMENT,
BLOCK_KERNEL_CONFIG_COMMITMENT,
PROOF_VERIFICATION_CONFIG_COMMITMENT,
EMPTY_WORD,
]Trait Implementations
Sourceimpl Clone for ProtocolConfig
impl Clone for ProtocolConfig
Sourcefn clone(&self) -> ProtocolConfig
fn clone(&self) -> ProtocolConfig
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ProtocolConfig
impl Debug for ProtocolConfig
Sourceimpl Deserializable for ProtocolConfig
impl Deserializable for ProtocolConfig
Sourcefn read_from<R: ByteReader>(
source: &mut R,
) -> Result<Self, DeserializationError>
fn read_from<R: ByteReader>( source: &mut R, ) -> Result<Self, DeserializationError>
source, attempts to deserialize these bytes
into Self, and returns the result. Read moreSourcefn min_serialized_size() -> usize
fn min_serialized_size() -> usize
Sourcefn read_from_bytes(bytes: &[u8]) -> Result<Self, DeserializationError>
fn read_from_bytes(bytes: &[u8]) -> Result<Self, DeserializationError>
Sourcefn read_from_bytes_with_budget(
bytes: &[u8],
budget: usize,
) -> Result<Self, DeserializationError>
fn read_from_bytes_with_budget( bytes: &[u8], budget: usize, ) -> Result<Self, DeserializationError>
Self from bytes with a byte budget limit. Read moreimpl Eq for ProtocolConfig
Sourceimpl PartialEq for ProtocolConfig
impl PartialEq for ProtocolConfig
Sourceimpl SequentialCommit for ProtocolConfig
impl SequentialCommit for ProtocolConfig
Sourcetype Commitment = Word
type Commitment = Word
Sourcefn to_elements(&self) -> Vec<Felt>
fn to_elements(&self) -> Vec<Felt>
Sourcefn to_commitment(&self) -> Self::Commitment
fn to_commitment(&self) -> Self::Commitment
Sourceimpl Serializable for ProtocolConfig
impl Serializable for ProtocolConfig
Sourcefn write_into<W: ByteWriter>(&self, target: &mut W)
fn write_into<W: ByteWriter>(&self, target: &mut W)
self into bytes and writes these bytes into the target.Sourcefn get_size_hint(&self) -> usize
fn get_size_hint(&self) -> usize
impl StructuralPartialEq for ProtocolConfig