Module transaction

Module transaction 

Modules

memory

Structs

AccountInputs
Contains information about an account, with everything required to execute a transaction.
ExecutedTransaction
Describes the result of executing a transaction program for the Miden protocol.
InputNoteCommitment
The commitment to an input note.
InputNotes
Input notes for a transaction, empty if the transaction does not consume notes.
OrderedTransactionHeaders
The ordered set of transaction headers in a ProvenBatch or ProvenBlock.
OutputNoteCollection
Contains a list of output notes of a transaction. The list can be empty if the transaction does not produce any notes.
PartialBlockchain
A partial view into the full Blockchain’s Merkle Mountain Range (MMR).
PrivateOutputNote
A NoteHeader of a private note, along with its public attachments.
ProvenTransaction
Result of executing and proving a transaction. Contains all the data required to verify that a transaction was executed correctly.
PublicOutputNote
A public output note with enforced size limits.
TransactionAdviceInputs
Advice inputs wrapper for inputs that are meant to be used exclusively in the transaction kernel.
TransactionArgs
Optional transaction arguments.
TransactionHeader
A transaction header derived from a ProvenTransaction.
TransactionId
A unique identifier of a transaction.
TransactionInputs
Contains the data required to execute a transaction.
TransactionKernel
TransactionMeasurements
Stores the resulting number of cycles for each transaction execution stage obtained from the TransactionProgress struct.
TransactionOutputs
Describes the result of executing a transaction.
TransactionScript
Transaction script.
TransactionScriptRoot
The MAST root of a TransactionScript.
TransactionSummary
The summary of the changes that result from executing a transaction.
TxAccountUpdate
Describes the changes made to the account state resulting from a transaction execution.

Enums

InputNote
An input note for a transaction.
OutputNote
Output note types that can appear in a proven transaction.
RawOutputNote
The types of note outputs produced during transaction execution (before proving).
TransactionEventId
Events which may be emitted by a transaction kernel.

Traits

ToInputNoteCommitments
Specifies the data used by the transaction kernel to commit to a note.

Type Aliases

OutputNotes
Output notes in a proven transaction.
RawOutputNotes
Output notes produced during transaction execution (before proving).