#[repr(u64)]pub enum TransactionEventId {
Show 37 variants
AccountBeforeForeignLoad = 6_972_941_848_080_861_924,
AccountVaultBeforeAddAsset = 18_303_204_740_946_329_635,
AccountVaultAfterAddAsset = 17_835_200_823_144_481_275,
AccountVaultBeforeRemoveAsset = 1_179_608_217_819_543_626,
AccountVaultAfterRemoveAsset = 13_199_791_703_193_557_058,
AccountVaultBeforeGetAsset = 5_427_381_176_639_432_259,
AccountStorageBeforeSetItem = 1_157_869_729_826_542_381,
AccountStorageAfterSetItem = 2_669_794_942_389_948_094,
AccountStorageBeforeGetMapItem = 11_218_463_077_671_809_423,
AccountStorageBeforeSetMapItem = 10_678_624_863_440_182_129,
AccountStorageAfterSetMapItem = 13_374_328_927_905_314_380,
AccountBeforeIncrementNonce = 5_470_444_885_890_284_488,
AccountAfterIncrementNonce = 4_726_967_953_768_030_579,
AccountPushProcedureIndex = 5_884_685_887_264_603_957,
NoteBeforeCreated = 18_345_177_884_634_440_934,
NoteAfterCreated = 13_036_925_679_091_902_935,
NoteBeforeAddAsset = 7_139_118_546_879_827_168,
NoteAfterAddAsset = 14_978_310_112_615_129_517,
NoteBeforeSetAttachment = 13_070_476_944_730_813_226,
AuthRequest = 13_241_364_899_378_198_653,
PrologueStart = 10_660_743_055_336_101_144,
PrologueEnd = 3_309_495_265_687_854_546,
NotesProcessingStart = 7_581_792_645_711_489_012,
NotesProcessingEnd = 9_572_255_952_805_370_620,
NoteExecutionStart = 17_301_901_040_384_301_731,
NoteExecutionEnd = 13_968_966_344_900_314_279,
TxScriptProcessingStart = 10_664_029_967_234_392_929,
TxScriptProcessingEnd = 14_870_446_584_323_844_107,
EpilogueStart = 9_010_968_242_891_569_239,
EpilogueEnd = 3_077_544_499_452_540_466,
EpilogueAuthProcStart = 9_454_851_594_144_374_864,
EpilogueAuthProcEnd = 4_160_790_277_174_525_418,
EpilogueAfterTxCyclesObtained = 15_740_160_240_184_961_248,
EpilogueBeforeTxFeeRemovedFromAccount = 1_055_134_351_081_964_750,
LinkMapSet = 3_518_868_871_657_695_033,
LinkMapGet = 13_360_626_129_449_169_220,
Unauthorized = 1_286_353_122_684_904_219,
}Expand description
Events which may be emitted by a transaction kernel.
The events are emitted via the emit.<event_id> instruction. The event ID is a Felt
derived from the EventId string which is used to identify the event type. Events emitted
by the transaction kernel are in the miden namespace.
Variants
AccountBeforeForeignLoad = 6_972_941_848_080_861_924
AccountVaultBeforeAddAsset = 18_303_204_740_946_329_635
AccountVaultAfterAddAsset = 17_835_200_823_144_481_275
AccountVaultBeforeRemoveAsset = 1_179_608_217_819_543_626
AccountVaultAfterRemoveAsset = 13_199_791_703_193_557_058
AccountVaultBeforeGetAsset = 5_427_381_176_639_432_259
AccountStorageBeforeSetItem = 1_157_869_729_826_542_381
AccountStorageAfterSetItem = 2_669_794_942_389_948_094
AccountStorageBeforeGetMapItem = 11_218_463_077_671_809_423
AccountStorageBeforeSetMapItem = 10_678_624_863_440_182_129
AccountStorageAfterSetMapItem = 13_374_328_927_905_314_380
AccountBeforeIncrementNonce = 5_470_444_885_890_284_488
AccountAfterIncrementNonce = 4_726_967_953_768_030_579
AccountPushProcedureIndex = 5_884_685_887_264_603_957
NoteBeforeCreated = 18_345_177_884_634_440_934
NoteAfterCreated = 13_036_925_679_091_902_935
NoteBeforeAddAsset = 7_139_118_546_879_827_168
NoteAfterAddAsset = 14_978_310_112_615_129_517
NoteBeforeSetAttachment = 13_070_476_944_730_813_226
AuthRequest = 13_241_364_899_378_198_653
PrologueStart = 10_660_743_055_336_101_144
PrologueEnd = 3_309_495_265_687_854_546
NotesProcessingStart = 7_581_792_645_711_489_012
NotesProcessingEnd = 9_572_255_952_805_370_620
NoteExecutionStart = 17_301_901_040_384_301_731
NoteExecutionEnd = 13_968_966_344_900_314_279
TxScriptProcessingStart = 10_664_029_967_234_392_929
TxScriptProcessingEnd = 14_870_446_584_323_844_107
EpilogueStart = 9_010_968_242_891_569_239
EpilogueEnd = 3_077_544_499_452_540_466
EpilogueAuthProcStart = 9_454_851_594_144_374_864
EpilogueAuthProcEnd = 4_160_790_277_174_525_418
EpilogueAfterTxCyclesObtained = 15_740_160_240_184_961_248
EpilogueBeforeTxFeeRemovedFromAccount = 1_055_134_351_081_964_750
LinkMapSet = 3_518_868_871_657_695_033
LinkMapGet = 13_360_626_129_449_169_220
Implementations