pub struct InputNoteCommitment { /* private fields */ }Expand description
The commitment to an input note.
For notes authenticated by the transaction kernel, the commitment consists only of the note’s nullifier. For notes whose authentication is delayed to batch/block kernels, the commitment also includes full note header (i.e., note ID and metadata).
Implementations
Sourceimpl InputNoteCommitment
impl InputNoteCommitment
Sourcepub fn from_parts_unchecked(
nullifier: Nullifier,
header: Option<NoteHeader>,
) -> Self
pub fn from_parts_unchecked( nullifier: Nullifier, header: Option<NoteHeader>, ) -> Self
Returns a new InputNoteCommitment instantiated from the provided nullifier and optional note header.
Note: this method does not validate that the provided nullifier and header are consistent with each other (i.e., it does not check that the nullifier was derived from the note referenced by the header).
Sourcepub fn nullifier(&self) -> Nullifier
pub fn nullifier(&self) -> Nullifier
Returns the nullifier of the input note committed to by this commitment.
Sourcepub fn header(&self) -> Option<&NoteHeader>
pub fn header(&self) -> Option<&NoteHeader>
Returns the header of the input committed to by this commitment.
Note headers are present only for notes whose presence in the change has not yet been authenticated.
Sourcepub fn is_authenticated(&self) -> bool
pub fn is_authenticated(&self) -> bool
Returns true if this commitment is for a note whose presence in the chain has been authenticated.
Authenticated notes are represented solely by their nullifiers and are missing the note header.