pub struct OutputNoteCollection<N> { /* private fields */ }Expand description
Contains a list of output notes of a transaction. The list can be empty if the transaction does not produce any notes.
This struct is generic over the note type N, allowing it to be used with both
RawOutputNote (in ExecutedTransaction) and
OutputNote (in ProvenTransaction).
Implementations
Sourceimpl<N> OutputNoteCollection<N>
impl<N> OutputNoteCollection<N>
Sourcepub fn new(notes: Vec<N>) -> Result<Self, TransactionOutputError>
pub fn new(notes: Vec<N>) -> Result<Self, TransactionOutputError>
Returns new OutputNoteCollection instantiated from the provided vector of notes.
Errors
Returns an error if:
- The total number of notes is greater than
MAX_OUTPUT_NOTES_PER_TX. - The vector of notes contains duplicates.
Sourcepub fn commitment(&self) -> Word
pub fn commitment(&self) -> Word
Returns the commitment to the output notes.
The commitment is computed as a sequential hash of (note_details_commitment, metadata_commitment) tuples for the notes created in a transaction.
Sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Returns true if this OutputNoteCollection does not contain any notes.
Sourcepub fn get_note(&self, idx: usize) -> &N
pub fn get_note(&self, idx: usize) -> &N
Returns a reference to the note located at the specified index.
Sourcepub fn iter(&self) -> impl Iterator<Item = &N>
pub fn iter(&self) -> impl Iterator<Item = &N>
Returns an iterator over notes in this OutputNoteCollection.