pub struct PrivateNoteHeader(/* private fields */);Expand description
A NoteHeader of a private note.
Implementations
Sourceimpl PrivateNoteHeader
impl PrivateNoteHeader
Sourcepub fn new(header: NoteHeader) -> Result<Self, OutputNoteError>
pub fn new(header: NoteHeader) -> Result<Self, OutputNoteError>
Creates a new PrivateNoteHeader from the given note header.
Errors
Returns an error if:
- The provided header is for a public note.
Sourcepub fn id(&self) -> NoteId
pub fn id(&self) -> NoteId
Returns the note’s identifier.
The NoteId value is both an unique identifier and a commitment to the note.
Sourcepub fn metadata(&self) -> &NoteMetadata
pub fn metadata(&self) -> &NoteMetadata
Returns the note’s metadata.
Sourcepub fn into_metadata(self) -> NoteMetadata
pub fn into_metadata(self) -> NoteMetadata
Consumes self and returns the note header’s metadata.
Sourcepub fn commitment(&self) -> Word
pub fn commitment(&self) -> Word
Returns a commitment to the note and its metadata.
hash(NOTE_ID || NOTE_METADATA_COMMITMENT)
This value is used primarily for authenticating notes consumed when they are consumed in a transaction.
Sourcepub fn as_header(&self) -> &NoteHeader
pub fn as_header(&self) -> &NoteHeader
Returns a reference to the underlying note header.
Sourcepub fn into_header(self) -> NoteHeader
pub fn into_header(self) -> NoteHeader
Consumes this wrapper and returns the underlying note header.