pub struct ProvenTransaction { /* private fields */ }Expand description
Result of executing and proving a transaction. Contains all the data required to verify that a transaction was executed correctly.
A proven transaction must not be empty. A transaction is empty if the account state is unchanged or the number of input notes is zero. This check prevents proving a transaction once and submitting it to the network many times. Output notes are not considered because they can be empty (i.e. contain no assets). Otherwise, a transaction with no account state change, no input notes and one such empty output note could be resubmitted many times to the network and fill up block space which is a form of DOS attack.
Implementations
Sourceimpl ProvenTransaction
impl ProvenTransaction
Sourcepub fn new(
account_update: TxAccountUpdate,
input_notes: impl IntoIterator<Item = impl Into<InputNoteCommitment>>,
output_notes: impl IntoIterator<Item = impl Into<OutputNote>>,
ref_block_num: BlockNumber,
ref_block_commitment: Word,
fee: FungibleAsset,
expiration_block_num: BlockNumber,
proof: ExecutionProof,
) -> Result<Self, ProvenTransactionError>
pub fn new( account_update: TxAccountUpdate, input_notes: impl IntoIterator<Item = impl Into<InputNoteCommitment>>, output_notes: impl IntoIterator<Item = impl Into<OutputNote>>, ref_block_num: BlockNumber, ref_block_commitment: Word, fee: FungibleAsset, expiration_block_num: BlockNumber, proof: ExecutionProof, ) -> Result<Self, ProvenTransactionError>
Creates a new ProvenTransaction from the specified components.
Errors
Returns an error if:
- The total number of input notes is greater than
MAX_INPUT_NOTES_PER_TX. - The vector of input notes contains duplicates.
- The total number of output notes is greater than
MAX_OUTPUT_NOTES_PER_TX. - The vector of output notes contains duplicates.
- The transaction is empty, which is the case if the account state is unchanged or the number of input notes is zero.
- The commitment computed on the actual account delta contained in
TxAccountUpdatedoes not match its declared account delta commitment.
Sourcepub fn id(&self) -> TransactionId
pub fn id(&self) -> TransactionId
Returns unique identifier of this transaction.
Sourcepub fn account_id(&self) -> AccountId
pub fn account_id(&self) -> AccountId
Returns ID of the account against which this transaction was executed.
Sourcepub fn account_update(&self) -> &TxAccountUpdate
pub fn account_update(&self) -> &TxAccountUpdate
Returns the account update details.
Sourcepub fn input_notes(&self) -> &InputNotes<InputNoteCommitment>
pub fn input_notes(&self) -> &InputNotes<InputNoteCommitment>
Returns a reference to the notes consumed by the transaction.
Sourcepub fn output_notes(&self) -> &OutputNotes
pub fn output_notes(&self) -> &OutputNotes
Returns a reference to the notes produced by the transaction.
Sourcepub fn proof(&self) -> &ExecutionProof
pub fn proof(&self) -> &ExecutionProof
Returns the proof of the transaction.
Sourcepub fn ref_block_num(&self) -> BlockNumber
pub fn ref_block_num(&self) -> BlockNumber
Returns the number of the reference block the transaction was executed against.
Sourcepub fn ref_block_commitment(&self) -> Word
pub fn ref_block_commitment(&self) -> Word
Returns the commitment of the block transaction was executed against.
Sourcepub fn fee(&self) -> FungibleAsset
pub fn fee(&self) -> FungibleAsset
Returns the fee of the transaction.
Sourcepub fn unauthenticated_notes(&self) -> impl Iterator<Item = &NoteHeader>
pub fn unauthenticated_notes(&self) -> impl Iterator<Item = &NoteHeader>
Returns an iterator of the headers of unauthenticated input notes in this transaction.
Sourcepub fn expiration_block_num(&self) -> BlockNumber
pub fn expiration_block_num(&self) -> BlockNumber
Returns the block number at which the transaction will expire.
Sourcepub fn nullifiers(&self) -> impl Iterator<Item = Nullifier> + '_
pub fn nullifiers(&self) -> impl Iterator<Item = Nullifier> + '_
Returns an iterator over the nullifiers of all input notes in this transaction.
This includes both authenticated and unauthenticated notes.