pub struct TransactionOutputs { /* private fields */ }Expand description
Describes the result of executing a transaction.
Implementations
Sourceimpl TransactionOutputs
impl TransactionOutputs
Sourcepub const OUTPUT_NOTES_COMMITMENT_WORD_IDX: usize = 0
pub const OUTPUT_NOTES_COMMITMENT_WORD_IDX: usize = 0
The element index starting from which the output notes commitment is stored on the output stack.
Sourcepub const ACCOUNT_UPDATE_COMMITMENT_WORD_IDX: usize = 4
pub const ACCOUNT_UPDATE_COMMITMENT_WORD_IDX: usize = 4
The element index starting from which the account update commitment word is stored on the output stack.
Sourcepub const EXPIRATION_BLOCK_ELEMENT_IDX: usize = 8
pub const EXPIRATION_BLOCK_ELEMENT_IDX: usize = 8
The index of the item at which the expiration block height is stored on the output stack.
Sourcepub fn new(
account: AccountHeader,
account_patch_commitment: Word,
output_notes: RawOutputNotes,
expiration_block_num: BlockNumber,
) -> Self
pub fn new( account: AccountHeader, account_patch_commitment: Word, output_notes: RawOutputNotes, expiration_block_num: BlockNumber, ) -> Self
Returns a new TransactionOutputs instantiated from the provided data.
Sourcepub fn account(&self) -> &AccountHeader
pub fn account(&self) -> &AccountHeader
Returns the header of the account’s final state.
Sourcepub fn account_patch_commitment(&self) -> Word
pub fn account_patch_commitment(&self) -> Word
Returns the commitment to the patch computed by the transaction kernel.
Sourcepub fn output_notes(&self) -> &RawOutputNotes
pub fn output_notes(&self) -> &RawOutputNotes
Returns the set of output notes created by the transaction.
Sourcepub fn expiration_block_num(&self) -> BlockNumber
pub fn expiration_block_num(&self) -> BlockNumber
Returns the block number at which the transaction will expire.
Sourcepub fn into_parts(self) -> (AccountHeader, RawOutputNotes)
pub fn into_parts(self) -> (AccountHeader, RawOutputNotes)
Consumes self and returns the individual parts (that are non-Copy).