pub struct TransactionSummaryUserParams { /* private fields */ }Expand description
The user-defined parameters bound by a TransactionSummary.
These are TransactionSummaryUserParams::NUM_ELEMENTS elements supplied by the account’s
authentication procedure when the summary is created.
The parameters are opaque: they are bound by the signature over the summary, but no meaning is enforced for any of them at the protocol level. Any semantics - using some of them as a salt for replay protection or binding a maximum fee, for example - must be implemented by the account component that supplies them.
Implementations
Sourceimpl TransactionSummaryUserParams
impl TransactionSummaryUserParams
Sourcepub const NUM_ELEMENTS: usize = 7
pub const NUM_ELEMENTS: usize = 7
The number of user-defined elements bound by a TransactionSummary.
Sourcepub fn new(elements: [Felt; 7]) -> Self
pub fn new(elements: [Felt; 7]) -> Self
Creates new TransactionSummaryUserParams from the provided elements.
Sourcepub fn as_elements(&self) -> &[Felt; 7]
pub fn as_elements(&self) -> &[Felt; 7]
Returns the user-defined elements in the order in which they are hashed into the
TransactionSummary commitment.