OutputNotes

Type Alias OutputNotes 

pub type OutputNotes = OutputNoteCollection<OutputNote>;
Output notes in a proven transaction.

Contains OutputNote instances which have been processed for inclusion in proven transactions, with size limits enforced on public notes.

Aliased Type

pub struct OutputNotes { /* private fields */ }