Skip to main content Module vm Copy item path Source AdviceInputs Inputs container to initialize advice provider for the execution of Miden VM programs. AdviceMap Defines a set of non-deterministic (advice) inputs which the VM can access by their keys. AttributeSet An AttributeSet provides storage and access to all of the attributes attached to a Miden
Assembly item, e.g. procedure definition. EventId A type-safe event identifier that semantically represents a Felt value. EventName A human-readable name for an event. ExecutionProof A proof of correct execution of Miden VM. Package A package is a assembled artifact containing: PackageManifest The manifest of a package, containing the set of package dependencies (libraries or packages)
and exported items (procedures, constants, types), if known. ProcedureExport A procedure exported by a package, along with its digest, signature, and attributes. Program An executable program for Miden VM. ProgramInfo A program information set consisting of its MAST root and set of kernel procedure roots used
for its compilation. QualifiedProcedureName Represents a qualified procedure name, e.g. std::math::u64::add, parsed into it’s
constituent Path and ProcedureName components. RowIndex A newtype wrapper around a usize value representing a step in the execution trace. Section SectionId A unique identifier for optional sections of the Miden package format StackInputs Defines the initial state of the VM’s operand stack. StackOutputs Defines the final state of the VM’s operand stack at the end of program execution. PackageExport Represents a named item exported from a package. SystemEvent Defines a set of actions which can be initiated from the VM to inject new data into the advice
provider. TargetType The type of a specific target provided by the current project FutureMaybeSend Alias for a Future