pub struct SectionId(/* private fields */);Expand description
A unique identifier for optional sections of the Miden package format
Implementations
Sourceimpl SectionId
impl SectionId
Sourcepub const DEBUG_TYPES: SectionId
pub const DEBUG_TYPES: SectionId
The section containing debug type definitions (primitives, structs, arrays, pointers, function types)
Sourcepub const DEBUG_SOURCES: SectionId
pub const DEBUG_SOURCES: SectionId
The section containing debug source file paths and checksums
Sourcepub const DEBUG_FUNCTIONS: SectionId
pub const DEBUG_FUNCTIONS: SectionId
The section containing debug function metadata, variables, and inlined calls
Sourcepub const ACCOUNT_COMPONENT_METADATA: SectionId
pub const ACCOUNT_COMPONENT_METADATA: SectionId
This section provides the encoded metadata for a compiled account component
Currently, this corresponds to the serialized representation of
miden-protocol::account::AccountComponentMetadata, i.e. name, descrioption, storage, that
is associated with this package.
Sourcepub const PROJECT_SOURCE_PROVENANCE: SectionId
pub const PROJECT_SOURCE_PROVENANCE: SectionId
This section contains provenance metadata for packages assembled from project sources.
Sourcepub const KERNEL: SectionId
pub const KERNEL: SectionId
This section contains the serialized kernel package linked against by an executable package.
Sourcepub fn custom(name: impl AsRef<str>) -> Result<SectionId, InvalidSectionIdError>
pub fn custom(name: impl AsRef<str>) -> Result<SectionId, InvalidSectionIdError>
Construct a user-defined (i.e. “custom”) section identifier
Section identifiers must be either an ASCII alphanumeric, or one of the following
characters: ., _, -. Additionally, the identifier must start with an ASCII alphabetic
character or _.