PackageDebugInfo

Type Alias PackageDebugInfo 

pub type PackageDebugInfo = DebugInfo<MastNodeId, DebugSourceNodeId>;
Package-owned debug information decoded from the well-known debug section.

The miden_core::serde::Deserializable::read_from and miden_core::serde::Deserializable::read_from_bytes implementations apply fixed resource limits for potentially adversarial input. Tools that deliberately accept the resource cost of larger debug information can use PackageDebugInfo::read_from_unmetered or PackageDebugInfo::read_from_bytes_unmetered.

Aliased Type

pub struct PackageDebugInfo { /* private fields */ }