#[repr(u8)]pub enum AccountType {
Private = 0,
Public = 1,
}Expand description
The type of an account, which determines where the account state is stored.
Variants
Private = 0
The account’s state is stored off-chain, and only a commitment to it is stored on-chain.
Public = 1
The account’s full state is stored on-chain.
Implementations
Sourceimpl AccountType
impl AccountType
Sourcepub const fn as_u8(self) -> u8
pub const fn as_u8(self) -> u8
Returns the account type encoded to a 1-bit flag, where private is 0 and public is 1.
Sourcepub fn is_public(&self) -> bool
pub fn is_public(&self) -> bool
Returns true if the account type is Self::Public, false otherwise.
Sourcepub fn is_private(&self) -> bool
pub fn is_private(&self) -> bool
Returns true if the account type is Self::Private, false otherwise.