The Assembler produces a Merkelized Abstract Syntax Tree (MAST) from Miden Assembly sources,
as a Package artifact. In general, packages come in three primary varieties:
This is a wrapper around the lower-level parser infrastructure which handles orchestrating all
of the pieces needed to parse a ast::Module from source, and run semantic analysis on it.
SourceManagerSync is a marker trait for SourceManager implementations that are also Send +
Sync, and is automatically implemented for any SourceManager that meets those requirements.