pub enum Asset {
Fungible(FungibleAsset),
NonFungible(NonFungibleAsset),
}Expand description
A fungible or a non-fungible asset.
All assets are encoded as the vault key of the asset and its value, each represented as one word (4 elements). This makes it is easy to determine the type of an asset both inside and outside Miden VM. Specifically:
The vault key of an asset contains the AccountId of the faucet that issues the asset. It can
be used to distinguish assets based on the encoded AccountId::account_type. In the vault
keys of assets, the account type bits at index 4 and 5 determine whether the asset is fungible
or non-fungible.
This property guarantees that there can never be a collision between a fungible and a non-fungible asset.
The methodology for constructing fungible and non-fungible assets is described below.
Fungible assets
- A fungible asset’s value layout is:
[amount, 0, 0, 0]. - A fungible asset’s vault key layout is:
[0, 0, faucet_id_suffix, faucet_id_prefix].
The most significant elements of a fungible asset’s key are set to the prefix
(faucet_id_prefix) and suffix (faucet_id_suffix) of the ID of the faucet which issues the
asset. The asset ID limbs are set to zero, which means two instances of the same fungible asset
have the same asset key and will be merged together when stored in the same account’s vault.
The least significant element of the value is set to the amount of the asset and the remaining
felts are zero. This amount cannot be greater than FungibleAsset::MAX_AMOUNT and thus fits
into a felt.
It is impossible to find a collision between two fungible assets issued by different faucets as the faucet ID is included in the description of the asset and this is guaranteed to be different for each faucet as per the faucet creation logic.
Non-fungible assets
- A non-fungible asset’s data layout is:
[hash0, hash1, hash2, hash3]. - A non-fungible asset’s vault key layout is:
[hash0, hash1, faucet_id_suffix, faucet_id_prefix].
The 4 elements of non-fungible assets are computed by hashing the asset data. This compresses an
asset of an arbitrary length to 4 field elements: [hash0, hash1, hash2, hash3].
It is impossible to find a collision between two non-fungible assets issued by different faucets as the faucet ID is included in the description of the non-fungible asset and this is guaranteed to be different as per the faucet creation logic.
The most significant elements of a non-fungible asset’s key are set to the prefix
(faucet_id_prefix) and suffix (faucet_id_suffix) of the ID of the faucet which issues the
asset. The asset ID limbs are set to hashes from the asset’s value. This means the collision
resistance of non-fungible assets issued by the same faucet is ~2^64, due to the 128-bit asset
ID that is unique per non-fungible asset. In other words, two non-fungible assets issued by the
same faucet are very unlikely to have the same asset key and thus should not collide when stored
in the same account’s vault.
Variants
Fungible(FungibleAsset)
NonFungible(NonFungibleAsset)
Implementations
Sourceimpl Asset
impl Asset
Sourcepub fn from_key_value(
key: AssetVaultKey,
value: Word,
) -> Result<Self, AssetError>
pub fn from_key_value( key: AssetVaultKey, value: Word, ) -> Result<Self, AssetError>
Sourcepub fn from_key_value_words(key: Word, value: Word) -> Result<Self, AssetError>
pub fn from_key_value_words(key: Word, value: Word) -> Result<Self, AssetError>
Creates an asset from the provided key and value.
Prefer Self::from_key_value for more type safety.
Errors
Returns an error if:
- The provided key does not contain a valid faucet ID.
Self::from_key_valuefails.
Sourcepub fn is_same(&self, other: &Self) -> bool
pub fn is_same(&self, other: &Self) -> bool
Returns true if this asset is the same as the specified asset.
Two assets are defined to be the same if:
- For fungible assets, if they were issued by the same faucet.
- For non-fungible assets, if the assets are identical.
Sourcepub fn is_fungible(&self) -> bool
pub fn is_fungible(&self) -> bool
Returns true if this asset is a fungible asset.
Sourcepub fn is_non_fungible(&self) -> bool
pub fn is_non_fungible(&self) -> bool
Returns true if this asset is a non fungible asset.
Sourcepub fn vault_key(&self) -> AssetVaultKey
pub fn vault_key(&self) -> AssetVaultKey
Returns the key which is used to store this asset in the account vault.
Sourcepub fn to_key_word(&self) -> Word
pub fn to_key_word(&self) -> Word
Returns the asset’s key encoded to a Word.
Sourcepub fn to_value_word(&self) -> Word
pub fn to_value_word(&self) -> Word
Returns the asset’s value encoded to a Word.
Sourcepub fn as_elements(&self) -> [Felt; 8]
pub fn as_elements(&self) -> [Felt; 8]
Returns the asset encoded as elements.
The first four elements contain the asset key and the last four elements contain the asset value.
Sourcepub fn unwrap_fungible(&self) -> FungibleAsset
pub fn unwrap_fungible(&self) -> FungibleAsset
Sourcepub fn unwrap_non_fungible(&self) -> NonFungibleAsset
pub fn unwrap_non_fungible(&self) -> NonFungibleAsset