pub struct AssetVaultKey { /* private fields */ }Expand description
The unique identifier of an Asset in the AssetVault.
Its Word layout is:
[
asset_id_suffix (64 bits),
asset_id_prefix (64 bits),
faucet_id_suffix (56 bits),
faucet_id_prefix (64 bits)
]See the Asset documentation for the differences between fungible and non-fungible assets.
Implementations
Sourceimpl AssetVaultKey
impl AssetVaultKey
Sourcepub fn new(asset_id: AssetId, faucet_id: AccountId) -> Result<Self, AssetError>
pub fn new(asset_id: AssetId, faucet_id: AccountId) -> Result<Self, AssetError>
Creates an AssetVaultKey from its parts.
Errors
Returns an error if:
- the provided ID is not of type
AccountType::FungibleFaucetorAccountType::NonFungibleFaucet - the asset ID limbs are not zero when
faucet_idis of typeAccountType::FungibleFaucet.
Sourcepub fn to_word(self) -> Word
pub fn to_word(self) -> Word
Returns the word representation of the vault key.
See the type-level documentation for details.
Sourcepub fn asset_id(&self) -> AssetId
pub fn asset_id(&self) -> AssetId
Returns the AssetId of the vault key that distinguishes different assets issued by the
same faucet.
Sourcepub fn faucet_id(&self) -> AccountId
pub fn faucet_id(&self) -> AccountId
Returns the AccountId of the faucet that issued the asset.
Sourcepub fn new_fungible(faucet_id: AccountId) -> Option<Self>
pub fn new_fungible(faucet_id: AccountId) -> Option<Self>
Constructs a fungible asset’s key from a faucet ID.
Returns None if the provided ID is not of type
AccountType::FungibleFaucet
Sourcepub fn to_leaf_index(&self) -> LeafIndex<SMT_DEPTH>
pub fn to_leaf_index(&self) -> LeafIndex<SMT_DEPTH>
Returns the leaf index of a vault key.