pub struct ProvenBlock { /* private fields */ }Expand description
Represents a block in the Miden blockchain that has been signed and proven.
Blocks transition through proposed, signed, and proven states. This struct represents the final, proven state of a block.
Proven blocks are the final, canonical blocks in the chain.
Implementations
Sourceimpl ProvenBlock
impl ProvenBlock
Sourcepub fn new(
header: BlockHeader,
body: BlockBody,
signature: Signature,
proof: BlockProof,
) -> Result<Self, ProvenBlockError>
pub fn new( header: BlockHeader, body: BlockBody, signature: Signature, proof: BlockProof, ) -> Result<Self, ProvenBlockError>
Returns a new ProvenBlock instantiated from the provided components.
Validates that the provided components correspond to each other by verifying the signature, and checking for matching transaction commitments and note roots.
Involves non-trivial computation. Use Self::new_unchecked if the validation is not
necessary.
Note: this does not fully validate the consistency of provided components. Specifically, we cannot validate that:
- That applying the account updates in the block body to the account tree represented by the root from the previous block header would actually result in the account root in the provided header.
- That inserting the created nullifiers in the block body to the nullifier tree represented by the root from the previous block header would actually result in the nullifier root in the provided header.
Errors
Returns an error if:
- If the validator signature does not verify against the block header commitment and the validator key.
- If the transaction commitment in the block header is inconsistent with the transactions included in the block body.
- If the note root in the block header is inconsistent with the notes included in the block body.
Sourcepub fn new_unchecked(
header: BlockHeader,
body: BlockBody,
signature: Signature,
proof: BlockProof,
) -> Self
pub fn new_unchecked( header: BlockHeader, body: BlockBody, signature: Signature, proof: BlockProof, ) -> Self
Returns a new ProvenBlock instantiated from the provided components.
Warning
This constructor does not do any validation as to whether the arguments correctly correspond to each other, which could cause errors downstream.
Sourcepub fn validate(&self) -> Result<(), ProvenBlockError>
pub fn validate(&self) -> Result<(), ProvenBlockError>
Validates that the components of the proven block correspond to each other by verifying the signature, and checking for matching transaction commitments and note roots.
Validation involves non-trivial computation, and depending on the size of the block may take non-negligible amount of time.
Note: this does not fully validate the consistency of internal components. Specifically, we cannot validate that:
- That applying the account updates in the block body to the account tree represented by the root from the previous block header would actually result in the account root in the provided header.
- That inserting the created nullifiers in the block body to the nullifier tree represented by the root from the previous block header would actually result in the nullifier root in the provided header.
Errors
Returns an error if:
- If the validator signature does not verify against the block header commitment and the validator key.
- If the transaction commitment in the block header is inconsistent with the transactions included in the block body.
- If the note root in the block header is inconsistent with the notes included in the block body.
Sourcepub fn proof_security_level(&self) -> u32
pub fn proof_security_level(&self) -> u32
Returns the proof security level of the block.
Sourcepub fn header(&self) -> &BlockHeader
pub fn header(&self) -> &BlockHeader
Returns the header of the block.
Sourcepub fn proof(&self) -> &BlockProof
pub fn proof(&self) -> &BlockProof
Returns the proof of the block.
Sourcepub fn into_parts(self) -> (BlockHeader, BlockBody, Signature, BlockProof)
pub fn into_parts(self) -> (BlockHeader, BlockBody, Signature, BlockProof)
Destructures this proven block into individual parts.