pub struct SignedBlock { /* private fields */ }Expand description
Represents a block in the Miden blockchain that has been signed by the Validator.
Signed blocks are applied to the chain’s state before they are proven.
Implementations
Sourceimpl SignedBlock
impl SignedBlock
Sourcepub fn new(
header: BlockHeader,
body: BlockBody,
signature: Signature,
) -> Result<Self, SignedBlockError>
pub fn new( header: BlockHeader, body: BlockBody, signature: Signature, ) -> Result<Self, SignedBlockError>
Returns a new SignedBlock instantiated from the provided components.
Validates that the provided components correspond to each other by verifying the signature, and checking for matching commitments and note roots.
Involves non-trivial computation. Use Self::new_unchecked if the validation is not
necessary.
Sourcepub fn new_unchecked(
header: BlockHeader,
body: BlockBody,
signature: Signature,
) -> Self
pub fn new_unchecked( header: BlockHeader, body: BlockBody, signature: Signature, ) -> Self
Returns a new SignedBlock instantiated from the provided components.
Warning
This constructor does not do any validation as to whether the arguments correctly correspond to each other, which could cause errors downstream.
Sourcepub fn header(&self) -> &BlockHeader
pub fn header(&self) -> &BlockHeader
Returns the header of the block.
Sourcepub fn into_parts(self) -> (BlockHeader, BlockBody, Signature)
pub fn into_parts(self) -> (BlockHeader, BlockBody, Signature)
Destructures this signed block into individual parts.
Sourcepub fn validate_parent(
&self,
parent_block: &BlockHeader,
) -> Result<(), SignedBlockError>
pub fn validate_parent( &self, parent_block: &BlockHeader, ) -> Result<(), SignedBlockError>
Validates that the provided parent block’s commitment and number correctly corresponds to the signed block.
Errors
Returns an error if:
- The signed block is the genesis block.
- The parent block number is not the signed block number - 1.
- The parent block’s commitment is not equal to the signed block’s previous block commitment.