Modules
Structs
- Account
Inputs - Contains information about an account, with everything required to execute a transaction.
- Executed
Transaction - Describes the result of executing a transaction program for the Miden protocol.
- Input
Note Commitment - The commitment to an input note.
- Input
Notes - Input notes for a transaction, empty if the transaction does not consume notes.
- Ordered
Transaction Headers - The ordered set of transaction headers in a
ProvenBatchorProvenBlock. - Output
Note Collection - Contains a list of output notes of a transaction. The list can be empty if the transaction does not produce any notes.
- Partial
Blockchain - A partial view into the full
Blockchain’s Merkle Mountain Range (MMR). - Private
Output Note - A
NoteHeaderof a private note, along with its public attachments. - Proven
Transaction - Result of executing and proving a transaction. Contains all the data required to verify that a transaction was executed correctly.
- Public
Output Note - A public output note with enforced size limits.
- Transaction
Advice Inputs - Advice inputs wrapper for inputs that are meant to be used exclusively in the transaction kernel.
- Transaction
Args - Optional transaction arguments.
- Transaction
Header - A transaction header derived from a
ProvenTransaction. - Transaction
Id - A unique identifier of a transaction.
- Transaction
Inputs - Contains the data required to execute a transaction.
- Transaction
Kernel - Transaction
Measurements - Stores the resulting number of cycles for each transaction execution stage obtained from the
TransactionProgressstruct. - Transaction
Outputs - Describes the result of executing a transaction.
- Transaction
Script - Transaction script.
- Transaction
Script Root - The MAST root of a
TransactionScript. - Transaction
Summary - The summary of the changes that result from executing a transaction.
- TxAccount
Update - Describes the changes made to the account state resulting from a transaction execution.
Enums
- Input
Note - An input note for a transaction.
- Output
Note - Output note types that can appear in a proven transaction.
- RawOutput
Note - The types of note outputs produced during transaction execution (before proving).
- Transaction
Event Id - Events which may be emitted by a transaction kernel.
Traits
- ToInput
Note Commitments - Specifies the data used by the transaction kernel to commit to a note.
Type Aliases
- Output
Notes - Output notes in a proven transaction.
- RawOutput
Notes - Output notes produced during transaction execution (before proving).