pub enum RawOutputNote {
Full(Note),
Partial(PartialNote),
}Expand description
The types of note outputs produced during transaction execution (before proving).
This enum represents notes as they exist immediately after transaction execution, before they are processed for inclusion in a proven transaction. It includes:
- Full notes with all details (public or private)
- Partial notes (notes created with only recipient digest, not full recipient details)
During proving, these are converted to OutputNote via the
to_output_note method, which enforces size limits on public notes and
converts private/partial notes to headers.
Variants
Full(Note)
Partial(PartialNote)
Implementations
Sourceimpl RawOutputNote
impl RawOutputNote
Sourcepub fn assets(&self) -> &NoteAssets
pub fn assets(&self) -> &NoteAssets
The assets contained in the note.
Sourcepub fn id(&self) -> NoteId
pub fn id(&self) -> NoteId
Unique note identifier.
This value is both an unique identifier and a commitment to the note.
Sourcepub fn recipient(&self) -> Option<&NoteRecipient>
pub fn recipient(&self) -> Option<&NoteRecipient>
Returns the recipient of the processed Full output note, None
if the note type is not Full.
See crate::note::NoteRecipient for more details.
Sourcepub fn recipient_digest(&self) -> Word
pub fn recipient_digest(&self) -> Word
Returns the recipient digest of the output note.
See crate::note::NoteRecipient for more details.
Sourcepub fn metadata(&self) -> &NoteMetadata
pub fn metadata(&self) -> &NoteMetadata
Returns the note’s metadata.
Sourcepub fn to_output_note(&self) -> Result<OutputNote, OutputNoteError>
pub fn to_output_note(&self) -> Result<OutputNote, OutputNoteError>
Converts this output note to a proven output note.
This method performs the following transformations:
- Private notes (full or partial) are converted into note headers (only public info retained).
- Full public notes are wrapped in
PublicOutputNote, which enforces size limits
Errors
Returns an error if a public note exceeds the maximum allowed size (NOTE_MAX_SIZE).
Sourcepub fn header(&self) -> &NoteHeader
pub fn header(&self) -> &NoteHeader
Returns a reference to the NoteHeader of this note.
Sourcepub fn commitment(&self) -> Word
pub fn commitment(&self) -> Word
Returns a commitment to the note and its metadata.
hash(NOTE_ID || NOTE_METADATA_COMMITMENT)