pub struct TransactionOutputs {
pub account: AccountHeader,
pub account_delta_commitment: Word,
pub output_notes: RawOutputNotes,
pub fee: FungibleAsset,
pub expiration_block_num: BlockNumber,
}Expand description
Describes the result of executing a transaction.
Fields
account: AccountHeaderInformation related to the account’s final state.
account_delta_commitment: WordThe commitment to the delta computed by the transaction kernel.
output_notes: RawOutputNotesSet of output notes created by the transaction.
fee: FungibleAssetThe fee of the transaction.
expiration_block_num: BlockNumberDefines up to which block the transaction is considered valid.
Implementations
Sourceimpl TransactionOutputs
impl TransactionOutputs
Sourcepub const OUTPUT_NOTES_COMMITMENT_WORD_IDX: usize = 0
pub const OUTPUT_NOTES_COMMITMENT_WORD_IDX: usize = 0
The element index starting from which the output notes commitment is stored on the output stack.
Sourcepub const ACCOUNT_UPDATE_COMMITMENT_WORD_IDX: usize = 4
pub const ACCOUNT_UPDATE_COMMITMENT_WORD_IDX: usize = 4
The element index starting from which the account update commitment word is stored on the output stack.
Sourcepub const NATIVE_ASSET_ID_SUFFIX_ELEMENT_IDX: usize = 8
pub const NATIVE_ASSET_ID_SUFFIX_ELEMENT_IDX: usize = 8
The index of the element at which the ID suffix of the faucet that issues the native asset is stored on the output stack.
Sourcepub const NATIVE_ASSET_ID_PREFIX_ELEMENT_IDX: usize = 9
pub const NATIVE_ASSET_ID_PREFIX_ELEMENT_IDX: usize = 9
The index of the element at which the ID prefix of the faucet that issues the native asset is stored on the output stack.
Sourcepub const FEE_AMOUNT_ELEMENT_IDX: usize = 10
pub const FEE_AMOUNT_ELEMENT_IDX: usize = 10
The index of the element at which the fee amount is stored on the output stack.
Sourcepub const EXPIRATION_BLOCK_ELEMENT_IDX: usize = 11
pub const EXPIRATION_BLOCK_ELEMENT_IDX: usize = 11
The index of the item at which the expiration block height is stored on the output stack.