pub struct TransactionScript { /* private fields */ }Expand description
Transaction script.
A transaction script is a program that is executed in a transaction after all input notes have been executed.
The TransactionScript object is composed of an executable program defined by a MastForest and an associated entrypoint.
Implementations
Sourceimpl TransactionScript
impl TransactionScript
Sourcepub fn new(code: Program) -> Self
pub fn new(code: Program) -> Self
Returns a new TransactionScript instantiated with the provided code.
Sourcepub fn from_parts(mast: Arc<MastForest>, entrypoint: MastNodeId) -> Self
pub fn from_parts(mast: Arc<MastForest>, entrypoint: MastNodeId) -> Self
Returns a new TransactionScript instantiated from the provided MAST forest and entrypoint.
Panics
Panics if the specified entrypoint is not in the provided MAST forest.
Sourcepub fn mast(&self) -> Arc<MastForest>
pub fn mast(&self) -> Arc<MastForest>
Returns a reference to the MastForest backing this transaction script.
Sourcepub fn root(&self) -> Word
pub fn root(&self) -> Word
Returns the commitment of this transaction script (i.e., the script’s MAST root).
Sourcepub fn with_advice_map(self, advice_map: AdviceMap) -> Self
pub fn with_advice_map(self, advice_map: AdviceMap) -> Self
Returns a new TransactionScript with the provided advice map entries merged into the underlying MastForest.
This allows adding advice map entries to an already-compiled transaction script, which is useful when the entries are determined after script compilation.