Module vm

Module vm 

Structs

AdviceInputs
Inputs container to initialize advice provider for the execution of Miden VM programs.
AdviceMap
Defines a set of non-deterministic (advice) inputs which the VM can access by their keys.
AdviceStack
Advice stack values ordered from top to bottom.
AttributeSet
An AttributeSet provides storage and access to all of the attributes attached to a Miden Assembly item, e.g. procedure definition.
DebugSourceNodeId
A strongly-typed index into the assembly source nodes table of PackageDebugInfo.
EventId
A type-safe event identifier that semantically represents a Felt value.
EventName
A human-readable name for an event.
ExecutionProof
A versioned Miden VM execution proof.
ExecutionProofCompatibility
The transport format and recursive verifier roots declared by an execution proof.
Package
A package is a assembled artifact containing:
PackageManifest
The manifest of a package, containing the set of package dependencies (libraries or packages) exported items (procedures, constants, types), and module surface information, if known.
ProcedureExport
A procedure exported by a package, along with its digest, signature, and attributes.
Program
An executable program for Miden VM.
ProgramInfo
A program information set consisting of its MAST root and set of kernel procedure roots used for its compilation.
ProofSecurityParameters
Security parameters of a verified Miden STARK proof.
QualifiedProcedureName
Represents a qualified procedure name, e.g. std::math::u64::add, parsed into it’s constituent Path and ProcedureName components.
RowIndex
A newtype wrapper around a usize value representing a step in the execution trace.
Section
SectionId
A unique identifier for optional sections of the Miden package format
StackInputs
Defines the initial state of the VM’s operand stack.
StackOutputs
Defines the final state of the VM’s operand stack at the end of program execution.
VerificationOutcome
Result of fully verifying an execution proof and all supplied STARKs.

Enums

PackageDebugInfoError
Errors raised while decoding trusted package-owned debug information.
PackageExport
Represents a named item exported from a package.
PrecompileStatus
The state of precompile work associated with an execution proof.
SystemEvent
Defines a set of host-side actions which can be initiated from the VM.
TargetType
The type of a specific target provided by the current project

Constants

MAX_PRECOMPILE_ROOTS
Hard library safety ceiling for ordered precompile roots.
MIN_STACK_DEPTH
Represents:

Traits

FutureMaybeSend
Alias for a Future

Type Aliases

PackageDebugInfo
Package-owned debug information decoded from the well-known debug section.